@@ -40,6 +40,7 @@ public class MetadataKeyHelper {
     private static final String PD_CONFIG = "PD_CONFIG";
     private static final String TASK_SPLIT = "TASK_SPLIT";
     private static final String TASK_MOVE = "TASK_MOVE";
+    private static final String TASK_BUILD_INDEX = "TASK_BI";
     private static final String LOG_RECORD = "LOG_RECORD";
 
     private static final String QUEUE = "QUEUE";
@@ -177,7 +178,7 @@ public class MetadataKeyHelper {
         String key = StringBuilderHelper.get()
                                         .append(PARTITION_STATUS)
                                         .append(DELIMITER)
-                                        .append(graphName).append(DELIMITER)
+                                        // .append(graphName).append(DELIMITER)
                                         .append(id).append(DELIMITER)
                                         .toString();
         return key.getBytes(Charset.defaultCharset());
@@ -273,7 +274,24 @@ public class MetadataKeyHelper {
         return builder.toString().getBytes(Charset.defaultCharset());
     }
 
-    public static byte[] getAllMoveTaskPrefix() {
+    public static byte[] getBuildIndexTaskKey(long taskId, int partitionId) {
+        // TASK_BI/ task id / partition id
+        StringBuilder builder = StringBuilderHelper.get()
+                                                   .append(TASK_BUILD_INDEX).append(DELIMITER)
+                                                   .append(taskId).append(DELIMITER)
+                                                   .append(partitionId);
+        return builder.toString().getBytes(Charset.defaultCharset());
+    }
+
+    public static byte[] getBuildIndexTaskPrefix(long taskId) {
+        // TASK_MOVE/{GraphName}/to PartitionID/{source partitionID}
+        StringBuilder builder = StringBuilderHelper.get()
+                                                   .append(TASK_BUILD_INDEX).append(DELIMITER)
+                                                   .append(taskId);
+        return builder.toString().getBytes(Charset.defaultCharset());
+    }
+
+    public static byte[] getAllMoveTaskPrefix(){
         // TASK_MOVE/{graphName}/toPartitionId/
         StringBuilder builder = StringBuilderHelper.get()
                                                    .append(TASK_MOVE).append(DELIMITER);
@@ -292,7 +310,7 @@ public class MetadataKeyHelper {
     }
 
     public static byte[] getLogKeyPrefix(String action, long time) {
-        //LOG_RECORD/{action}/{time}/
+        //LOG_DATA_SPLIT/{time}/{GraphName}
         StringBuilder builder = StringBuilderHelper.get()
                                                    .append(LOG_RECORD)
                                                    .append(DELIMITER)
