@@ -17,6 +17,10 @@
 
 package org.apache.hugegraph.pd.common;
 
+import org.apache.hugegraph.pd.common.MetadataKeyHelperTest;
+import org.apache.hugegraph.pd.service.IdServiceTest;
+import org.apache.hugegraph.pd.service.KvServiceTest;
+import lombok.extern.slf4j.Slf4j;
 import org.junit.runner.RunWith;
 import org.junit.runners.Suite;
 
@@ -26,8 +30,11 @@ import lombok.extern.slf4j.Slf4j;
 @Suite.SuiteClasses({
         PartitionUtilsTest.class,
         PartitionCacheTest.class,
+        MetadataKeyHelperTest.class,
+        KvServiceTest.class,
         HgAssertTest.class,
         KVPairTest.class,
+        IdServiceTest.class
 })
 @Slf4j
 public class CommonSuiteTest {
