@@ -20,7 +20,6 @@ package org.apache.hugegraph.api.auth;
 import java.util.List;
 
 import org.apache.commons.lang3.StringUtils;
-import org.apache.hugegraph.HugeGraph;
 import org.apache.hugegraph.api.API;
 import org.apache.hugegraph.api.filter.StatusFilter.Status;
 import org.apache.hugegraph.auth.HugeUser;
@@ -52,7 +51,7 @@ import jakarta.ws.rs.Produces;
 import jakarta.ws.rs.QueryParam;
 import jakarta.ws.rs.core.Context;
 
-@Path("graphs/{graph}/auth/users")
+@Path("graphspaces/{graphspace}/auth/users")
 @Singleton
 @Tag(name = "UserAPI")
 public class UserAPI extends API {
@@ -65,15 +64,14 @@ public class UserAPI extends API {
     @Consumes(APPLICATION_JSON)
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String create(@Context GraphManager manager,
-                         @PathParam("graph") String graph,
+                         @PathParam("graphspace") String graphSpace,
                          JsonUser jsonUser) {
-        LOG.debug("Graph [{}] create user: {}", graph, jsonUser);
+        LOG.debug("GraphSpace [{}] create user: {}", graphSpace, jsonUser);
         checkCreatingBody(jsonUser);
 
-        HugeGraph g = graph(manager, graph);
         HugeUser user = jsonUser.build();
         user.id(manager.authManager().createUser(user));
-        return manager.serializer(g).writeAuthElement(user);
+        return manager.serializer().writeAuthElement(user);
     }
 
     @PUT
@@ -82,13 +80,12 @@ public class UserAPI extends API {
     @Consumes(APPLICATION_JSON)
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String update(@Context GraphManager manager,
-                         @PathParam("graph") String graph,
+                         @PathParam("graphspace") String graphSpace,
                          @PathParam("id") String id,
                          JsonUser jsonUser) {
-        LOG.debug("Graph [{}] update user: {}", graph, jsonUser);
+        LOG.debug("GraphSpace [{}] update user: {}", graphSpace, jsonUser);
         checkUpdatingBody(jsonUser);
 
-        HugeGraph g = graph(manager, graph);
         HugeUser user;
         try {
             user = manager.authManager().getUser(UserAPI.parseId(id));
@@ -97,20 +94,19 @@ public class UserAPI extends API {
         }
         user = jsonUser.build(user);
         manager.authManager().updateUser(user);
-        return manager.serializer(g).writeAuthElement(user);
+        return manager.serializer().writeAuthElement(user);
     }
 
     @GET
     @Timed
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String list(@Context GraphManager manager,
-                       @PathParam("graph") String graph,
+                       @PathParam("graphspace") String graphSpace,
                        @QueryParam("limit") @DefaultValue("100") long limit) {
-        LOG.debug("Graph [{}] list users", graph);
+        LOG.debug("GraphSpace [{}] list users", graphSpace);
 
-        HugeGraph g = graph(manager, graph);
         List<HugeUser> users = manager.authManager().listAllUsers(limit);
-        return manager.serializer(g).writeAuthElements("users", users);
+        return manager.serializer().writeAuthElements("users", users);
     }
 
     @GET
@@ -118,13 +114,12 @@ public class UserAPI extends API {
     @Path("{id}")
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String get(@Context GraphManager manager,
-                      @PathParam("graph") String graph,
+                      @PathParam("graphspace") String graphSpace,
                       @PathParam("id") String id) {
-        LOG.debug("Graph [{}] get user: {}", graph, id);
+        LOG.debug("GraphSpace [{}] get user: {}", graphSpace, id);
 
-        HugeGraph g = graph(manager, graph);
         HugeUser user = manager.authManager().getUser(IdGenerator.of(id));
-        return manager.serializer(g).writeAuthElement(user);
+        return manager.serializer().writeAuthElement(user);
     }
 
     @GET
@@ -132,12 +127,10 @@ public class UserAPI extends API {
     @Path("{id}/role")
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String role(@Context GraphManager manager,
-                       @PathParam("graph") String graph,
+                       @PathParam("graphspace") String graphSpace,
                        @PathParam("id") String id) {
-        LOG.debug("Graph [{}] get user role: {}", graph, id);
+        LOG.debug("GraphSpace [{}] get user role: {}", graphSpace, id);
 
-        @SuppressWarnings("unused") // just check if the graph exists
-        HugeGraph g = graph(manager, graph);
         HugeUser user = manager.authManager().getUser(IdGenerator.of(id));
         return manager.authManager().rolePermission(user).toJson();
     }
@@ -147,12 +140,10 @@ public class UserAPI extends API {
     @Path("{id}")
     @Consumes(APPLICATION_JSON)
     public void delete(@Context GraphManager manager,
-                       @PathParam("graph") String graph,
+                       @PathParam("graphspace") String graphSpace,
                        @PathParam("id") String id) {
-        LOG.debug("Graph [{}] delete user: {}", graph, id);
+        LOG.debug("GraphSpace [{}] delete user: {}", graphSpace, id);
 
-        @SuppressWarnings("unused") // just check if the graph exists
-        HugeGraph g = graph(manager, graph);
         try {
             manager.authManager().deleteUser(IdGenerator.of(id));
         } catch (NotFoundException e) {
