@@ -71,7 +71,7 @@ import jakarta.ws.rs.Produces;
 import jakarta.ws.rs.QueryParam;
 import jakarta.ws.rs.core.Context;
 
-@Path("graphs/{graph}/graph/vertices")
+@Path("graphspaces/{graphspace}/graphs/{graph}/graph/vertices")
 @Singleton
 @Tag(name = "VertexAPI")
 public class VertexAPI extends BatchAPI {
@@ -83,17 +83,18 @@ public class VertexAPI extends BatchAPI {
     @Status(Status.CREATED)
     @Consumes(APPLICATION_JSON)
     @Produces(APPLICATION_JSON_WITH_CHARSET)
-    @RolesAllowed({"admin", "$owner=$graph $action=vertex_write"})
+    @RolesAllowed({"space_member", "$owner=$graph $action=vertex_write"})
     public String create(@Context GraphManager manager,
+                         @PathParam("graphspace") String graphSpace,
                          @PathParam("graph") String graph,
                          JsonVertex jsonVertex) {
         LOG.debug("Graph [{}] create vertex: {}", graph, jsonVertex);
         checkCreatingBody(jsonVertex);
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         Vertex vertex = commit(g, () -> g.addVertex(jsonVertex.properties()));
 
-        return manager.serializer(g).writeVertex(vertex);
+        return manager.serializer().writeVertex(vertex);
     }
 
     @POST
@@ -103,23 +104,24 @@ public class VertexAPI extends BatchAPI {
     @Status(Status.CREATED)
     @Consumes(APPLICATION_JSON)
     @Produces(APPLICATION_JSON_WITH_CHARSET)
-    @RolesAllowed({"admin", "$owner=$graph $action=vertex_write"})
+    @RolesAllowed({"space_member", "$owner=$graph $action=vertex_write"})
     public String create(@Context HugeConfig config,
                          @Context GraphManager manager,
+                         @PathParam("graphspace") String graphSpace,
                          @PathParam("graph") String graph,
                          List<JsonVertex> jsonVertices) {
         LOG.debug("Graph [{}] create vertices: {}", graph, jsonVertices);
         checkCreatingBody(jsonVertices);
         checkBatchSize(config, jsonVertices);
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
 
         return this.commit(config, g, jsonVertices.size(), () -> {
             List<Id> ids = new ArrayList<>(jsonVertices.size());
             for (JsonVertex vertex : jsonVertices) {
                 ids.add((Id) g.addVertex(vertex.properties()).id());
             }
-            return manager.serializer(g).writeIds(ids);
+            return manager.serializer().writeIds(ids);
         });
     }
 
@@ -135,9 +137,10 @@ public class VertexAPI extends BatchAPI {
     @Path("batch")
     @Consumes(APPLICATION_JSON)
     @Produces(APPLICATION_JSON_WITH_CHARSET)
-    @RolesAllowed({"admin", "$owner=$graph $action=vertex_write"})
+    @RolesAllowed({"space_member", "$owner=$graph $action=vertex_write"})
     public String update(@Context HugeConfig config,
                          @Context GraphManager manager,
+                         @PathParam("graphspace") String graphSpace,
                          @PathParam("graph") String graph,
                          BatchVertexRequest req) {
         BatchVertexRequest.checkUpdate(req);
@@ -145,7 +148,7 @@ public class VertexAPI extends BatchAPI {
         checkUpdatingBody(req.jsonVertices);
         checkBatchSize(config, req.jsonVertices);
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         Map<Id, JsonVertex> map = new HashMap<>(req.jsonVertices.size());
 
         return this.commit(config, g, 0, () -> {
@@ -175,7 +178,7 @@ public class VertexAPI extends BatchAPI {
             });
 
             // If return ids, the ids.size() maybe different with the origins'
-            return manager.serializer(g).writeVertices(vertices.iterator(), false);
+            return manager.serializer().writeVertices(vertices.iterator(), false);
         });
     }
 
@@ -184,8 +187,9 @@ public class VertexAPI extends BatchAPI {
     @Path("{id}")
     @Consumes(APPLICATION_JSON)
     @Produces(APPLICATION_JSON_WITH_CHARSET)
-    @RolesAllowed({"admin", "$owner=$graph $action=vertex_write"})
+    @RolesAllowed({"space_member", "$owner=$graph $action=vertex_write"})
     public String update(@Context GraphManager manager,
+                         @PathParam("graphspace") String graphSpace,
                          @PathParam("graph") String graph,
                          @PathParam("id") String idValue,
                          @QueryParam("action") String action,
@@ -197,7 +201,7 @@ public class VertexAPI extends BatchAPI {
         // Parse action param
         boolean append = checkAndParseAction(action);
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         HugeVertex vertex = (HugeVertex) g.vertex(id);
         VertexLabel vertexLabel = vertex.schemaLabel();
 
@@ -211,15 +215,17 @@ public class VertexAPI extends BatchAPI {
 
         commit(g, () -> updateProperties(vertex, jsonVertex, append));
 
-        return manager.serializer(g).writeVertex(vertex);
+        return manager.serializer().writeVertex(vertex);
     }
 
     @GET
     @Timed
     @Compress
     @Produces(APPLICATION_JSON_WITH_CHARSET)
-    @RolesAllowed({"admin", "$owner=$graph $action=vertex_read"})
+    @RolesAllowed({"space", "$graphspace=$graphspace $owner=$graph " +
+                            "$action=vertex_read"})
     public String list(@Context GraphManager manager,
+                       @PathParam("graphspace") String graphSpace,
                        @PathParam("graph") String graph,
                        @QueryParam("label") String label,
                        @QueryParam("properties") String properties,
@@ -235,10 +241,11 @@ public class VertexAPI extends BatchAPI {
         Map<String, Object> props = parseProperties(properties);
         if (page != null) {
             E.checkArgument(offset == 0,
-                            "Not support querying vertices based on paging and offset together");
+                            "Not support querying vertices based on paging " +
+                            "and offset together");
         }
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
 
         GraphTraversal<Vertex, Vertex> traversal = g.traversal().V();
         if (label != null) {
@@ -265,7 +272,7 @@ public class VertexAPI extends BatchAPI {
         }
 
         try {
-            return manager.serializer(g).writeVertices(traversal, page != null);
+            return manager.serializer().writeVertices(traversal, page != null);
         } finally {
             if (g.tx().isOpen()) {
                 g.tx().close();
@@ -277,17 +284,18 @@ public class VertexAPI extends BatchAPI {
     @Timed
     @Path("{id}")
     @Produces(APPLICATION_JSON_WITH_CHARSET)
-    @RolesAllowed({"admin", "$owner=$graph $action=vertex_read"})
+    @RolesAllowed({"space_member", "$owner=$graph $action=vertex_read"})
     public String get(@Context GraphManager manager,
+                      @PathParam("graphspace") String graphSpace,
                       @PathParam("graph") String graph,
                       @PathParam("id") String idValue) {
         LOG.debug("Graph [{}] get vertex by id '{}'", graph, idValue);
 
         Id id = checkAndParseVertexId(idValue);
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         try {
             Vertex vertex = g.vertex(id);
-            return manager.serializer(g).writeVertex(vertex);
+            return manager.serializer().writeVertex(vertex);
         } finally {
             if (g.tx().isOpen()) {
                 g.tx().close();
@@ -299,15 +307,16 @@ public class VertexAPI extends BatchAPI {
     @Timed
     @Path("{id}")
     @Consumes(APPLICATION_JSON)
-    @RolesAllowed({"admin", "$owner=$graph $action=vertex_delete"})
+    @RolesAllowed({"space_member", "$owner=$graph $action=vertex_delete"})
     public void delete(@Context GraphManager manager,
+                       @PathParam("graphspace") String graphSpace,
                        @PathParam("graph") String graph,
                        @PathParam("id") String idValue,
                        @QueryParam("label") String label) {
         LOG.debug("Graph [{}] remove vertex by id '{}'", graph, idValue);
 
         Id id = checkAndParseVertexId(idValue);
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         commit(g, () -> {
             try {
                 g.removeVertex(label, id);
