@@ -62,7 +62,7 @@ import jakarta.ws.rs.Produces;
 import jakarta.ws.rs.QueryParam;
 import jakarta.ws.rs.core.Context;
 
-@Path("graphs/{graph}/schema/propertykeys")
+@Path("graphspaces/{graphspace}/graphs/{graph}/schema/propertykeys")
 @Singleton
 @Tag(name = "PropertyKeyAPI")
 public class PropertyKeyAPI extends API {
@@ -74,18 +74,20 @@ public class PropertyKeyAPI extends API {
     @Status(Status.ACCEPTED)
     @Consumes(APPLICATION_JSON)
     @Produces(APPLICATION_JSON_WITH_CHARSET)
-    @RolesAllowed({"admin", "$owner=$graph $action=property_key_write"})
+    @RolesAllowed({"space_member", "$graphspace=$graphspace $owner=$graph " +
+                            "$action=property_key_write"})
     @RedirectFilter.RedirectMasterRole
     public String create(@Context GraphManager manager,
+                         @PathParam("graphspace") String graphSpace,
                          @PathParam("graph") String graph,
                          JsonPropertyKey jsonPropertyKey) {
         LOG.debug("Graph [{}] create property key: {}", graph, jsonPropertyKey);
         checkCreatingBody(jsonPropertyKey);
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         PropertyKey.Builder builder = jsonPropertyKey.convert2Builder(g);
         SchemaElement.TaskWithSchema pk = builder.createWithTask();
-        return manager.serializer(g).writeTaskWithSchema(pk);
+        return manager.serializer().writeTaskWithSchema(pk);
     }
 
     @PUT
@@ -94,9 +96,11 @@ public class PropertyKeyAPI extends API {
     @Path("{name}")
     @Consumes(APPLICATION_JSON)
     @Produces(APPLICATION_JSON_WITH_CHARSET)
-    @RolesAllowed({"admin", "$owner=$graph $action=property_key_write"})
+    @RolesAllowed({"space_member", "$graphspace=$graphspace $owner=$graph " +
+                            "$action=property_key_write"})
     @RedirectFilter.RedirectMasterRole
     public String update(@Context GraphManager manager,
+                         @PathParam("graphspace") String graphSpace,
                          @PathParam("graph") String graph,
                          @PathParam("name") String name,
                          @QueryParam("action") String action,
@@ -108,7 +112,7 @@ public class PropertyKeyAPI extends API {
                         "The name in url(%s) and body(%s) are different",
                         name, jsonPropertyKey.name);
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         if (ACTION_CLEAR.equals(action)) {
             PropertyKey propertyKey = g.propertyKey(name);
             E.checkArgument(propertyKey.olap(),
@@ -117,7 +121,7 @@ public class PropertyKeyAPI extends API {
             Id id = g.clearPropertyKey(propertyKey);
             SchemaElement.TaskWithSchema pk =
                     new SchemaElement.TaskWithSchema(propertyKey, id);
-            return manager.serializer(g).writeTaskWithSchema(pk);
+            return manager.serializer().writeTaskWithSchema(pk);
         }
 
         // Parse action parameter
@@ -129,14 +133,16 @@ public class PropertyKeyAPI extends API {
                                   builder.eliminate();
         SchemaElement.TaskWithSchema pk =
                 new SchemaElement.TaskWithSchema(propertyKey, IdGenerator.ZERO);
-        return manager.serializer(g).writeTaskWithSchema(pk);
+        return manager.serializer().writeTaskWithSchema(pk);
     }
 
     @GET
     @Timed
     @Produces(APPLICATION_JSON_WITH_CHARSET)
-    @RolesAllowed({"admin", "$owner=$graph $action=property_key_read"})
+    @RolesAllowed({"space_member", "$graphspace=$graphspace $owner=$graph " +
+                            "$action=property_key_read"})
     public String list(@Context GraphManager manager,
+                       @PathParam("graphspace") String graphSpace,
                        @PathParam("graph") String graph,
                        @QueryParam("names") List<String> names) {
         boolean listAll = CollectionUtils.isEmpty(names);
@@ -146,7 +152,7 @@ public class PropertyKeyAPI extends API {
             LOG.debug("Graph [{}] get property keys by names {}", graph, names);
         }
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         List<PropertyKey> propKeys;
         if (listAll) {
             propKeys = g.schema().getPropertyKeys();
@@ -156,22 +162,24 @@ public class PropertyKeyAPI extends API {
                 propKeys.add(g.schema().getPropertyKey(name));
             }
         }
-        return manager.serializer(g).writePropertyKeys(propKeys);
+        return manager.serializer().writePropertyKeys(propKeys);
     }
 
     @GET
     @Timed
     @Path("{name}")
     @Produces(APPLICATION_JSON_WITH_CHARSET)
-    @RolesAllowed({"admin", "$owner=$graph $action=property_key_read"})
+    @RolesAllowed({"space_member", "$graphspace=$graphspace $owner=$graph " +
+                            "$action=property_key_read"})
     public String get(@Context GraphManager manager,
+                      @PathParam("graphspace") String graphSpace,
                       @PathParam("graph") String graph,
                       @PathParam("name") String name) {
         LOG.debug("Graph [{}] get property key by name '{}'", graph, name);
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         PropertyKey propertyKey = g.schema().getPropertyKey(name);
-        return manager.serializer(g).writePropertyKey(propertyKey);
+        return manager.serializer().writePropertyKey(propertyKey);
     }
 
     @DELETE
@@ -180,14 +188,16 @@ public class PropertyKeyAPI extends API {
     @Path("{name}")
     @Consumes(APPLICATION_JSON)
     @Produces(APPLICATION_JSON_WITH_CHARSET)
-    @RolesAllowed({"admin", "$owner=$graph $action=property_key_delete"})
+    @RolesAllowed({"space_member", "$graphspace=$graphspace $owner=$graph " +
+                            "$action=property_key_delete"})
     @RedirectFilter.RedirectMasterRole
     public Map<String, Id> delete(@Context GraphManager manager,
+                                  @PathParam("graphspace") String graphSpace,
                                   @PathParam("graph") String graph,
                                   @PathParam("name") String name) {
         LOG.debug("Graph [{}] remove property key by name '{}'", graph, name);
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         // Throw 404 if not exists
         g.schema().getPropertyKey(name);
         return ImmutableMap.of("task_id",
