@@ -39,7 +39,7 @@ import jakarta.ws.rs.PathParam;
 import jakarta.ws.rs.Produces;
 import jakarta.ws.rs.core.Context;
 
-@Path("graphs/{graph}/schema")
+@Path("graphspaces/{graphspace}/graphs/{graph}/schema")
 @Singleton
 @Tag(name = "SchemaAPI")
 public class SchemaAPI extends API {
@@ -49,12 +49,14 @@ public class SchemaAPI extends API {
     @GET
     @Timed
     @Produces(APPLICATION_JSON_WITH_CHARSET)
-    @RolesAllowed({"admin", "$owner=$graph $action=schema_read"})
+    @RolesAllowed({"space_member", "$graphspace=$graphspace $owner=$graph " +
+                            "$action=schema_read"})
     public String list(@Context GraphManager manager,
+                       @PathParam("graphspace") String graphSpace,
                        @PathParam("graph") String graph) {
         LOG.debug("Graph [{}] list all schema", graph);
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         SchemaManager schema = g.schema();
 
         Map<String, List<?>> schemaMap = new LinkedHashMap<>(4);
@@ -63,6 +65,6 @@ public class SchemaAPI extends API {
         schemaMap.put("edgelabels", schema.getEdgeLabels());
         schemaMap.put("indexlabels", schema.getIndexLabels());
 
-        return manager.serializer(g).writeMap(schemaMap);
+        return manager.serializer().writeMap(schemaMap);
     }
 }
