@@ -49,7 +49,7 @@ import jakarta.ws.rs.core.Context;
  * info and definition in:
  * https://en.wikipedia.org/wiki/Adamic/Adar_index
  */
-@Path("graphs/{graph}/traversers/adamicadar")
+@Path("graphspaces/{graphspace}/graphs/{graph}/traversers/adamicadar")
 @Singleton
 @Tag(name = "AdamicAdarAPI")
 public class AdamicAdarAPI extends API {
@@ -59,6 +59,7 @@ public class AdamicAdarAPI extends API {
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String get(@Context GraphManager manager,
                       @PathParam("graph") String graph,
+                      @PathParam("graphspace") String graphSpace,
                       @QueryParam("vertex") String current,
                       @QueryParam("other") String other,
                       @QueryParam("direction") String direction,
@@ -78,7 +79,7 @@ public class AdamicAdarAPI extends API {
                         "The source and target vertex id can't be same");
         Directions dir = Directions.convert(EdgeAPI.parseDirection(direction));
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         try (PredictionTraverser traverser = new PredictionTraverser(g)) {
             double score = traverser.adamicAdar(sourceId, targetId, dir,
                                                 edgeLabel, maxDegree, limit);
