@@ -50,7 +50,7 @@ import jakarta.ws.rs.PathParam;
 import jakarta.ws.rs.Produces;
 import jakarta.ws.rs.core.Context;
 
-@Path("graphs/{graph}/traversers/count")
+@Path("graphspaces/{graphspace}/graphs/{graph}/traversers/count")
 @Singleton
 @Tag(name = "CountAPI")
 public class CountAPI extends API {
@@ -61,6 +61,7 @@ public class CountAPI extends API {
     @Timed
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String post(@Context GraphManager manager,
+                       @PathParam("graphspace") String graphSpace,
                        @PathParam("graph") String graph,
                        CountRequest request) {
         LOG.debug("Graph [{}] get count from '{}' with request {}",
@@ -78,13 +79,13 @@ public class CountAPI extends API {
                                "must >= 0 or == -1, but got: '%s'",
                                request.dedupSize);
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         List<EdgeStep> steps = steps(g, request);
         CountTraverser traverser = new CountTraverser(g);
         long count = traverser.count(sourceId, steps, request.containsTraversed,
                                      request.dedupSize);
 
-        return manager.serializer(g).writeMap(ImmutableMap.of("count", count));
+        return manager.serializer().writeMap(ImmutableMap.of("count", count));
     }
 
     private static List<EdgeStep> steps(HugeGraph graph, CountRequest request) {
