@@ -42,6 +42,7 @@ import org.apache.hugegraph.type.define.Directions;
 import org.apache.hugegraph.util.E;
 import org.apache.hugegraph.util.Log;
 import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
 import org.slf4j.Logger;
 
 import com.codahale.metrics.annotation.Timed;
@@ -61,7 +62,7 @@ import jakarta.ws.rs.Produces;
 import jakarta.ws.rs.QueryParam;
 import jakarta.ws.rs.core.Context;
 
-@Path("graphs/{graph}/traversers/kneighbor")
+@Path("graphspaces/{graphspace}/graphs/{graph}/traversers/kneighbor")
 @Singleton
 @Tag(name = "KneighborAPI")
 public class KneighborAPI extends TraverserAPI {
@@ -72,6 +73,7 @@ public class KneighborAPI extends TraverserAPI {
     @Timed
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String get(@Context GraphManager manager,
+                      @PathParam("graphspace") String graphSpace,
                       @PathParam("graph") String graph,
                       @QueryParam("source") String sourceV,
                       @QueryParam("direction") String direction,
@@ -94,7 +96,7 @@ public class KneighborAPI extends TraverserAPI {
         Id source = VertexAPI.checkAndParseVertexId(sourceV);
         Directions dir = Directions.convert(EdgeAPI.parseDirection(direction));
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
 
         Set<Id> ids;
         try (KneighborTraverser traverser = new KneighborTraverser(g)) {
@@ -115,6 +117,7 @@ public class KneighborAPI extends TraverserAPI {
     @Consumes(APPLICATION_JSON)
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String post(@Context GraphManager manager,
+                       @PathParam("graphspace") String graphSpace,
                        @PathParam("graph") String graph,
                        Request request) {
         E.checkArgumentNotNull(request, "The request body can't be null");
@@ -136,7 +139,7 @@ public class KneighborAPI extends TraverserAPI {
 
         ApiMeasurer measure = new ApiMeasurer();
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         Id sourceId = HugeVertex.getIdValue(request.source);
 
         Steps steps = steps(g, request.steps);
@@ -169,7 +172,7 @@ public class KneighborAPI extends TraverserAPI {
                                               QueryResults.emptyIterator());
         }
 
-        Iterator<?> iterVertex;
+        Iterator<Vertex> iterVertex = Collections.emptyIterator();
         Set<Id> vertexIds = new HashSet<>(neighbors);
         if (request.withPath) {
             for (HugeTraverser.Path p : paths) {
@@ -179,18 +182,12 @@ public class KneighborAPI extends TraverserAPI {
         if (request.withVertex && !vertexIds.isEmpty()) {
             iterVertex = g.vertices(vertexIds.toArray());
             measure.addIterCount(vertexIds.size(), 0L);
-        } else {
-            iterVertex = vertexIds.iterator();
         }
 
-        Iterator<?> iterEdge = Collections.emptyIterator();
-        if (request.withPath) {
+        Iterator<Edge> iterEdge = Collections.emptyIterator();
+        if (request.withPath && request.withEdge) {
             Set<Edge> edges = results.edgeResults().getEdges(paths);
-            if (request.withEdge) {
-                iterEdge = edges.iterator();
-            } else {
-                iterEdge = HugeTraverser.EdgeRecord.getEdgeIds(edges).iterator();
-            }
+            iterEdge = edges.iterator();
         }
 
         return manager.serializer(g, measure.measures())
