@@ -62,7 +62,7 @@ import jakarta.ws.rs.Produces;
 import jakarta.ws.rs.QueryParam;
 import jakarta.ws.rs.core.Context;
 
-@Path("graphs/{graph}/traversers/kout")
+@Path("graphspaces/{graphspace}/graphs/{graph}/traversers/kout")
 @Singleton
 @Tag(name = "KoutAPI")
 public class KoutAPI extends TraverserAPI {
@@ -73,6 +73,7 @@ public class KoutAPI extends TraverserAPI {
     @Timed
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String get(@Context GraphManager manager,
+                      @PathParam("graphspace") String graphSpace,
                       @PathParam("graph") String graph,
                       @QueryParam("source") String source,
                       @QueryParam("direction") String direction,
@@ -99,7 +100,7 @@ public class KoutAPI extends TraverserAPI {
         Id sourceId = VertexAPI.checkAndParseVertexId(source);
         Directions dir = Directions.convert(EdgeAPI.parseDirection(direction));
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
 
         Set<Id> ids;
         try (KoutTraverser traverser = new KoutTraverser(g)) {
@@ -121,6 +122,7 @@ public class KoutAPI extends TraverserAPI {
     @Consumes(APPLICATION_JSON)
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String post(@Context GraphManager manager,
+                       @PathParam("graphspace") String graphSpace,
                        @PathParam("graph") String graph,
                        Request request) {
         E.checkArgumentNotNull(request, "The request body can't be null");
@@ -145,7 +147,7 @@ public class KoutAPI extends TraverserAPI {
 
         ApiMeasurer measure = new ApiMeasurer();
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         Id sourceId = HugeVertex.getIdValue(request.source);
 
         Steps steps = steps(g, request.steps);
