@@ -54,7 +54,7 @@ import jakarta.ws.rs.Produces;
 import jakarta.ws.rs.QueryParam;
 import jakarta.ws.rs.core.Context;
 
-@Path("graphs/{graph}/traversers/sameneighbors")
+@Path("graphspaces/{graphspace}/graphs/{graph}/traversers/sameneighbors")
 @Singleton
 @Tag(name = "SameNeighborsAPI")
 public class SameNeighborsAPI extends API {
@@ -65,6 +65,7 @@ public class SameNeighborsAPI extends API {
     @Timed
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String get(@Context GraphManager manager,
+                      @PathParam("graphspace") String graphSpace,
                       @PathParam("graph") String graph,
                       @QueryParam("vertex") String vertex,
                       @QueryParam("other") String other,
@@ -84,7 +85,7 @@ public class SameNeighborsAPI extends API {
         Id targetId = VertexAPI.checkAndParseVertexId(other);
         Directions dir = Directions.convert(EdgeAPI.parseDirection(direction));
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         SameNeighborTraverser traverser = new SameNeighborTraverser(g);
         Set<Id> neighbors = traverser.sameNeighbors(sourceId, targetId, dir,
                                                     edgeLabel, maxDegree, limit);
@@ -100,6 +101,7 @@ public class SameNeighborsAPI extends API {
     @Timed
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String sameNeighbors(@Context GraphManager manager,
+                                @PathParam("graphspace") String graphSpace,
                                 @PathParam("graph") String graph,
                                 Request request) {
         LOG.debug("Graph [{}] get same neighbors among batch, '{}'", graph, request.toString());
@@ -107,7 +109,7 @@ public class SameNeighborsAPI extends API {
         ApiMeasurer measure = new ApiMeasurer();
 
         Directions dir = Directions.convert(EdgeAPI.parseDirection(request.direction));
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         SameNeighborTraverser traverser = new SameNeighborTraverser(g);
 
         List<Object> vertexList = request.vertexList;
