@@ -49,7 +49,7 @@ import jakarta.ws.rs.Produces;
 import jakarta.ws.rs.QueryParam;
 import jakarta.ws.rs.core.Context;
 
-@Path("graphs/{graph}/traversers/singlesourceshortestpath")
+@Path("graphspaces/{graphspace}/graphs/{graph}/traversers/singlesourceshortestpath")
 @Singleton
 @Tag(name = "SingleSourceShortestPathAPI")
 public class SingleSourceShortestPathAPI extends API {
@@ -60,6 +60,7 @@ public class SingleSourceShortestPathAPI extends API {
     @Timed
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String get(@Context GraphManager manager,
+                      @PathParam("graphspace") String graphSpace,
                       @PathParam("graph") String graph,
                       @QueryParam("source") String source,
                       @QueryParam("direction") String direction,
@@ -89,7 +90,7 @@ public class SingleSourceShortestPathAPI extends API {
         Id sourceId = VertexAPI.checkAndParseVertexId(source);
         Directions dir = Directions.convert(EdgeAPI.parseDirection(direction));
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         SingleSourceShortestPathTraverser traverser =
                 new SingleSourceShortestPathTraverser(g);
         SingleSourceShortestPathTraverser.WeightedPaths paths =
