@@ -48,7 +48,7 @@ import jakarta.ws.rs.Produces;
 import jakarta.ws.rs.QueryParam;
 import jakarta.ws.rs.core.Context;
 
-@Path("graphs/{graph}/traversers/vertices")
+@Path("graphspaces/{graphspace}/graphs/{graph}/traversers/vertices")
 @Singleton
 @Tag(name = "VerticesAPI")
 public class VerticesAPI extends API {
@@ -60,6 +60,7 @@ public class VerticesAPI extends API {
     @Compress
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String list(@Context GraphManager manager,
+                       @PathParam("graphspace") String graphSpace,
                        @PathParam("graph") String graph,
                        @QueryParam("ids") List<String> stringIds) {
         LOG.debug("Graph [{}] get vertices by ids: {}", graph, stringIds);
@@ -72,10 +73,10 @@ public class VerticesAPI extends API {
             ids[i] = VertexAPI.checkAndParseVertexId(stringIds.get(i));
         }
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
 
         Iterator<Vertex> vertices = g.vertices(ids);
-        return manager.serializer(g).writeVertices(vertices, false);
+        return manager.serializer().writeVertices(vertices, false);
     }
 
     @GET
@@ -84,14 +85,15 @@ public class VerticesAPI extends API {
     @Compress
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String shards(@Context GraphManager manager,
+                         @PathParam("graphspace") String graphSpace,
                          @PathParam("graph") String graph,
                          @QueryParam("split_size") long splitSize) {
         LOG.debug("Graph [{}] get vertex shards with split size '{}'",
                   graph, splitSize);
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         List<Shard> shards = g.metadata(HugeType.VERTEX, "splits", splitSize);
-        return manager.serializer(g).writeList("shards", shards);
+        return manager.serializer().writeList("shards", shards);
     }
 
     @GET
@@ -100,6 +102,7 @@ public class VerticesAPI extends API {
     @Compress
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String scan(@Context GraphManager manager,
+                       @PathParam("graphspace") String graphSpace,
                        @PathParam("graph") String graph,
                        @QueryParam("start") String start,
                        @QueryParam("end") String end,
@@ -109,7 +112,7 @@ public class VerticesAPI extends API {
         LOG.debug("Graph [{}] query vertices by shard(start: {}, end: {}, " +
                   "page: {}) ", graph, start, end, page);
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
 
         ConditionQuery query = new ConditionQuery(HugeType.VERTEX);
         query.scan(start, end);
@@ -119,6 +122,6 @@ public class VerticesAPI extends API {
         }
         Iterator<Vertex> vertices = g.vertices(query);
 
-        return manager.serializer(g).writeVertices(vertices, query.paging());
+        return manager.serializer().writeVertices(vertices, query.paging());
     }
 }
