@@ -51,7 +51,7 @@ import jakarta.ws.rs.Produces;
 import jakarta.ws.rs.QueryParam;
 import jakarta.ws.rs.core.Context;
 
-@Path("graphs/{graph}/traversers/weightedshortestpath")
+@Path("graphspaces/{graphspace}/graphs/{graph}/traversers/weightedshortestpath")
 @Singleton
 @Tag(name = "WeightedShortestPathAPI")
 public class WeightedShortestPathAPI extends API {
@@ -62,6 +62,7 @@ public class WeightedShortestPathAPI extends API {
     @Timed
     @Produces(APPLICATION_JSON_WITH_CHARSET)
     public String get(@Context GraphManager manager,
+                      @PathParam("graphspace") String graphSpace,
                       @PathParam("graph") String graph,
                       @QueryParam("source") String source,
                       @QueryParam("target") String target,
@@ -91,7 +92,7 @@ public class WeightedShortestPathAPI extends API {
         Directions dir = Directions.convert(EdgeAPI.parseDirection(direction));
         E.checkArgumentNotNull(weight, "The weight property can't be null");
 
-        HugeGraph g = graph(manager, graph);
+        HugeGraph g = graph(manager, graphSpace, graph);
         SingleSourceShortestPathTraverser traverser =
                 new SingleSourceShortestPathTraverser(g);
 
