@@ -66,10 +66,9 @@ import com.google.common.collect.ImmutableSet;
 
 public final class HugeFactoryAuthProxy {
 
-    private static final Logger LOG = Log.logger(HugeFactoryAuthProxy.class);
     public static final String GRAPH_FACTORY =
             "gremlin.graph=org.apache.hugegraph.auth.HugeFactoryAuthProxy";
-
+    private static final Logger LOG = Log.logger(HugeFactoryAuthProxy.class);
     private static final Set<String> PROTECT_METHODS = ImmutableSet.of("instance");
 
     private static final Map<HugeGraph, HugeGraph> GRAPHS = new HashMap<>();
@@ -498,8 +497,6 @@ public final class HugeFactoryAuthProxy {
         Reflection.registerMethodsToFilter(loadClass("java.lang.ProcessImpl"), "forkAndExec",
                                            "setAccessible", "start");
 
-        optionalMethodsToFilter("sun.invoke.util.BytecodeDescriptor", "parseMethod", "parseSig");
-        optionalMethodsToFilter("sun.reflect.misc.MethodUtil", "invoke");
         optionalMethodsToFilter("jdk.internal.reflect.MethodAccessor", "invoke");
         optionalMethodsToFilter("jdk.internal.reflect.NativeMethodAccessorImpl", "invoke");
     }
@@ -636,8 +633,8 @@ public final class HugeFactoryAuthProxy {
         try {
             clazz = Class.forName(className);
         } catch (ClassNotFoundException e) {
-            // TODO: we just ignore the exception, change it after we drop Java8 support
-            LOG.warn("Skip register class {} to filter", className);
+            LOG.debug("Internal class {} not found in this JDK implementation, skipping filter " +
+                      "registration", className, e);
         }
         if (clazz != null) {
             Reflection.registerMethodsToFilter(clazz, methodNames);
