@@ -21,6 +21,7 @@ import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.Date;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Objects;
@@ -49,6 +50,7 @@ import org.apache.hugegraph.backend.id.IdGenerator;
 import org.apache.hugegraph.backend.query.Query;
 import org.apache.hugegraph.backend.store.BackendFeatures;
 import org.apache.hugegraph.backend.store.BackendStoreInfo;
+import org.apache.hugegraph.backend.store.BackendStoreProvider;
 import org.apache.hugegraph.backend.store.raft.RaftGroupManager;
 import org.apache.hugegraph.config.AuthOptions;
 import org.apache.hugegraph.config.HugeConfig;
@@ -56,6 +58,7 @@ import org.apache.hugegraph.config.TypedOption;
 import org.apache.hugegraph.exception.NotSupportException;
 import org.apache.hugegraph.iterator.FilterIterator;
 import org.apache.hugegraph.iterator.MapperIterator;
+import org.apache.hugegraph.kvstore.KvStore;
 import org.apache.hugegraph.masterelection.GlobalMasterInfo;
 import org.apache.hugegraph.masterelection.RoleElectionStateMachine;
 import org.apache.hugegraph.rpc.RpcServiceConfig4Client;
@@ -110,21 +113,23 @@ import jakarta.ws.rs.NotAuthorizedException;
 
 public final class HugeGraphAuthProxy implements HugeGraph {
 
+    private static final Logger LOG = Log.logger(HugeGraphAuthProxy.class);
+    private static final ThreadLocal<Context> CONTEXTS = new InheritableThreadLocal<>();
+    private static final ThreadLocal<String> REQUEST_GRAPH_SPACE = new ThreadLocal<>();
+
     static {
         HugeGraph.registerTraversalStrategies(HugeGraphAuthProxy.class);
     }
 
-    private static final Logger LOG = Log.logger(HugeGraphAuthProxy.class);
     private final Cache<Id, UserWithRole> usersRoleCache;
     private final Cache<Id, RateLimiter> auditLimiters;
     private final double auditLogMaxRate;
-
     private final HugeGraph hugegraph;
     private final TaskSchedulerProxy taskScheduler;
     private final AuthManagerProxy authManager;
 
     public HugeGraphAuthProxy(HugeGraph hugegraph) {
-        LOG.info("Wrap graph '{}' with HugeGraphAuthProxy", hugegraph.name());
+        LOG.info("Wrap graph '{}' with HugeGraphAuthProxy", hugegraph.spaceGraphName());
         HugeConfig config = (HugeConfig) hugegraph.configuration();
         long expired = config.get(AuthOptions.AUTH_CACHE_EXPIRE);
         long capacity = config.get(AuthOptions.AUTH_CACHE_CAPACITY);
@@ -141,12 +146,83 @@ public final class HugeGraphAuthProxy implements HugeGraph {
         LOG.info("Audit log rate limit is {}/s", this.auditLogMaxRate);
     }
 
+    static Context setContext(Context context) {
+        Context old = CONTEXTS.get();
+        CONTEXTS.set(context);
+        return old;
+    }
+
+    public static void resetContext() {
+        CONTEXTS.remove();
+        REQUEST_GRAPH_SPACE.remove();
+    }
+
+    public static void resetSpaceContext() {
+        CONTEXTS.remove();
+        REQUEST_GRAPH_SPACE.remove();
+    }
+
+    /**
+     * Get the graph space from current request URL path
+     */
+    public static String getRequestGraphSpace() {
+        return REQUEST_GRAPH_SPACE.get();
+    }
+
+    /**
+     * Set the graph space from current request URL path
+     * This is used for permission check when operating global resources like User/Group
+     */
+    public static void setRequestGraphSpace(String graphSpace) {
+        REQUEST_GRAPH_SPACE.set(graphSpace);
+    }
+
+    public static Context setAdmin() {
+        Context old = getContext();
+        AuthContext.useAdmin();
+        return old;
+    }
+
+    public static Context getContext() {
+        // Return task context first
+        String taskContext = TaskManager.getContext();
+        User user = User.fromJson(taskContext);
+        if (user != null) {
+            return new Context(user);
+        }
+
+        return CONTEXTS.get();
+    }
+
+    private static String getContextString() {
+        Context context = getContext();
+        if (context == null) {
+            return null;
+        }
+        return context.user().toJson();
+    }
+
+    static void logUser(User user, String path) {
+        LOG.info("User '{}' login from client [{}] with path '{}'",
+                 user.username(), user.client(), path);
+    }
+
     @Override
     public HugeGraph hugegraph() {
         this.verifyAdminPermission();
         return this.hugegraph;
     }
 
+    @Override
+    public KvStore kvStore() {
+        return this.hugegraph.kvStore();
+    }
+
+    @Override
+    public void kvStore(KvStore kvStore) {
+        this.hugegraph.kvStore(kvStore);
+    }
+
     @Override
     public <C extends GraphComputer> C compute(Class<C> clazz)
             throws IllegalArgumentException {
@@ -180,6 +256,11 @@ public final class HugeGraphAuthProxy implements HugeGraph {
         return schema;
     }
 
+    @Override
+    public BackendStoreProvider storeProvider() {
+        return this.hugegraph.storeProvider();
+    }
+
     @Override
     public Id getNextId(HugeType type) {
         if (type == HugeType.TASK) {
@@ -552,6 +633,17 @@ public final class HugeGraphAuthProxy implements HugeGraph {
 
     }
 
+    @Override
+    public String graphSpace() {
+        // none verify permission
+        return this.hugegraph.graphSpace();
+    }
+
+    @Override
+    public void graphSpace(String graphSpace) {
+        this.hugegraph.graphSpace(graphSpace);
+    }
+
     @Override
     public Transaction tx() {
         /*
@@ -622,6 +714,11 @@ public final class HugeGraphAuthProxy implements HugeGraph {
         return this.hugegraph.name();
     }
 
+    @Override
+    public String spaceGraphName() {
+        return this.hugegraph.spaceGraphName();
+    }
+
     @Override
     public String backend() {
         this.verifyAnyPermission();
@@ -670,6 +767,12 @@ public final class HugeGraphAuthProxy implements HugeGraph {
         this.hugegraph.waitReady(rpcServer);
     }
 
+    @Override
+    public void waitStarted() {
+        this.verifyAnyPermission();
+        this.hugegraph.waitStarted();
+    }
+
     @Override
     public void serverStarted(GlobalMasterInfo nodeInfo) {
         this.verifyAdminPermission();
@@ -682,6 +785,12 @@ public final class HugeGraphAuthProxy implements HugeGraph {
         return this.hugegraph.started();
     }
 
+    @Override
+    public void started(boolean started) {
+        this.verifyAdminPermission();
+        this.hugegraph.started(started);
+    }
+
     @Override
     public boolean closed() {
         this.verifyAdminPermission();
@@ -752,7 +861,8 @@ public final class HugeGraphAuthProxy implements HugeGraph {
         try {
             this.hugegraph.truncateBackend();
         } finally {
-            if (admin != null && StandardAuthManager.isLocal(userManager)) {
+            if (admin != null && userManager.findUser(HugeAuthenticator.USER_ADMIN) == null &&
+                StandardAuthManager.isLocal(userManager)) {
                 // Restore admin user to continue to do any operation
                 userManager.createUser(admin);
             }
@@ -795,9 +905,57 @@ public final class HugeGraphAuthProxy implements HugeGraph {
         return this.hugegraph.cloneConfig(newGraph);
     }
 
+    @Override
+    public String nickname() {
+        return this.hugegraph.nickname();
+    }
+
+    @Override
+    public void nickname(String nickname) {
+        this.verifyAnyPermission();
+        this.hugegraph.nickname(nickname);
+    }
+
+    @Override
+    public String creator() {
+        this.verifyAnyPermission();
+        return this.hugegraph.creator();
+    }
+
+    @Override
+    public void creator(String creator) {
+        this.verifyAnyPermission();
+        this.hugegraph.creator(creator);
+    }
+
+    @Override
+    public Date createTime() {
+        this.verifyAnyPermission();
+        return this.hugegraph.createTime();
+    }
+
+    @Override
+    public void createTime(Date createTime) {
+        this.verifyAnyPermission();
+        this.hugegraph.createTime(createTime);
+
+    }
+
+    @Override
+    public Date updateTime() {
+        this.verifyAnyPermission();
+        return this.hugegraph.updateTime();
+    }
+
+    @Override
+    public void updateTime(Date updateTime) {
+        this.verifyAnyPermission();
+        this.hugegraph.updateTime(updateTime);
+    }
+
     private <V> Cache<Id, V> cache(String prefix, long capacity,
                                    long expiredTime) {
-        String name = prefix + "-" + this.hugegraph.name();
+        String name = prefix + "-" + this.hugegraph.spaceGraphName();
         Cache<Id, V> cache = CacheManager.instance().cache(name, capacity);
         if (expiredTime > 0L) {
             cache.expire(Duration.ofSeconds(expiredTime).toMillis());
@@ -808,7 +966,7 @@ public final class HugeGraphAuthProxy implements HugeGraph {
     }
 
     private void verifyAdminPermission() {
-        verifyPermission(HugePermission.ANY, ResourceType.ROOT);
+        verifyPermission(HugePermission.ADMIN, ResourceType.ROOT);
     }
 
     private void verifyStatusPermission() {
@@ -828,8 +986,19 @@ public final class HugeGraphAuthProxy implements HugeGraph {
          */
         verifyResPermission(actionPerm, true, () -> {
             String graph = this.hugegraph.name();
+
+            // For global resources like USER_GROUP, use request graph space from HugeGraphAuthProxy
+            // instead of the graph space where authManager is located
+            String graphSpace = this.graphSpace();
+            String requestGraphSpace = HugeGraphAuthProxy.getRequestGraphSpace();
+
+            if (requestGraphSpace != null) {
+                graphSpace = requestGraphSpace;
+                LOG.debug("Using requestGraphSpace: {}", graphSpace);
+            }
+
             Nameable elem = HugeResource.NameObject.ANY;
-            return ResourceObject.of(graph, resType, elem);
+            return ResourceObject.of(graphSpace, graph, resType, elem);
         });
     }
 
@@ -859,9 +1028,24 @@ public final class HugeGraphAuthProxy implements HugeGraph {
         return verifyResPermission(actionPerm, throwIfNoPerm, () -> {
             String graph = this.hugegraph.name();
             V elem = elementFetcher.get();
+
+            // For global resources like USER_GROUP, use request graph space from HugeGraphAuthProxy
+            // instead of the graph space where authManager is located
+            String graphSpace = this.graphSpace();
+            String requestGraphSpace = HugeGraphAuthProxy.getRequestGraphSpace();
+
+            LOG.debug(
+                    "verifyUserPermission: elem.type()={}, graphSpace={}, requestGraphSpace={}, " +
+                    "isGrantOrUser={}",
+                    elem.type(), graphSpace, requestGraphSpace, elem.type().isGrantOrUser());
+
+            if (requestGraphSpace != null) {
+                graphSpace = requestGraphSpace;
+                LOG.debug("Using requestGraphSpace: {}", graphSpace);
+            }
+            
             @SuppressWarnings("unchecked")
-            ResourceObject<V> r = (ResourceObject<V>) ResourceObject.of(graph,
-                                                                        elem);
+            ResourceObject<V> r = (ResourceObject<V>) ResourceObject.of(graphSpace, graph, elem);
             return r;
         });
     }
@@ -893,7 +1077,7 @@ public final class HugeGraphAuthProxy implements HugeGraph {
             String graph = this.hugegraph.name();
             HugeElement elem = (HugeElement) elementFetcher.get();
             @SuppressWarnings("unchecked")
-            ResourceObject<V> r = (ResourceObject<V>) ResourceObject.of(graph,
+            ResourceObject<V> r = (ResourceObject<V>) ResourceObject.of(this.graphSpace(), graph,
                                                                         elem);
             return r;
         });
@@ -908,7 +1092,17 @@ public final class HugeGraphAuthProxy implements HugeGraph {
         verifyResPermission(actionPerm, true, () -> {
             String graph = this.hugegraph.name();
             Nameable elem = HugeResource.NameObject.of(name);
-            return ResourceObject.of(graph, resType, elem);
+
+            // For global resources like USER_GROUP, use request graph space from HugeGraphAuthProxy
+            // instead of the graph space where authManager is located
+            String graphSpace = this.graphSpace();
+            String requestGraphSpace = HugeGraphAuthProxy.getRequestGraphSpace();
+
+            if (requestGraphSpace != null) {
+                graphSpace = requestGraphSpace;
+            }
+
+            return ResourceObject.of(graphSpace, graph, resType, elem);
         });
     }
 
@@ -944,7 +1138,7 @@ public final class HugeGraphAuthProxy implements HugeGraph {
             String graph = this.hugegraph.name();
             SchemaElement elem = schemaFetcher.get();
             @SuppressWarnings("unchecked")
-            ResourceObject<V> r = (ResourceObject<V>) ResourceObject.of(graph,
+            ResourceObject<V> r = (ResourceObject<V>) ResourceObject.of(this.graphSpace(), graph,
                                                                         elem);
             return r;
         });
@@ -1016,6 +1210,61 @@ public final class HugeGraphAuthProxy implements HugeGraph {
         return result;
     }
 
+    public static class Context {
+
+        private static final Context ADMIN = new Context(User.ADMIN);
+
+        private final User user;
+
+        public Context(User user) {
+            E.checkNotNull(user, "user");
+            this.user = user;
+        }
+
+        public static Context admin() {
+            return ADMIN;
+        }
+
+        public User user() {
+            return this.user;
+        }
+    }
+
+    static class ContextTask implements Runnable {
+
+        private final Runnable runner;
+        private final Context context;
+
+        public ContextTask(Runnable runner) {
+            this.context = getContext();
+            this.runner = runner;
+        }
+
+        @Override
+        public void run() {
+            setContext(this.context);
+            try {
+                this.runner.run();
+            } finally {
+                resetContext();
+            }
+        }
+    }
+
+    public static class ContextThreadPoolExecutor extends ThreadPoolExecutor {
+
+        public ContextThreadPoolExecutor(int corePoolSize, int maxPoolSize,
+                                         ThreadFactory threadFactory) {
+            super(corePoolSize, maxPoolSize, 0L, TimeUnit.MILLISECONDS,
+                  new LinkedBlockingQueue<>(), threadFactory);
+        }
+
+        @Override
+        public void execute(Runnable command) {
+            super.execute(new ContextTask(command));
+        }
+    }
+
     class TaskSchedulerProxy implements TaskScheduler {
 
         private final TaskScheduler taskScheduler;
@@ -1150,6 +1399,11 @@ public final class HugeGraphAuthProxy implements HugeGraph {
             return this.taskScheduler.graphName();
         }
 
+        @Override
+        public String spaceGraphName() {
+            return taskScheduler.spaceGraphName();
+        }
+
         @Override
         public void taskDone(HugeTask<?> task) {
             verifyAnyPermission();
@@ -1180,7 +1434,7 @@ public final class HugeGraphAuthProxy implements HugeGraph {
                 String graph = HugeGraphAuthProxy.this.hugegraph.name();
                 String name = task.id().toString();
                 Nameable elem = HugeResource.NameObject.of(name);
-                return ResourceObject.of(graph, ResourceType.TASK, elem);
+                return ResourceObject.of(graphSpace(), graph, ResourceType.TASK, elem);
             }, () -> {
                 return hasTaskPermission(task);
             });
@@ -1245,7 +1499,6 @@ public final class HugeGraphAuthProxy implements HugeGraph {
             E.checkArgument(!HugeAuthenticator.USER_ADMIN.equals(user.name()),
                             "Invalid user name '%s'", user.name());
             this.updateCreator(user);
-            verifyUserPermission(HugePermission.WRITE, user);
             return this.authManager.createUser(user);
         }
 
@@ -1254,8 +1507,10 @@ public final class HugeGraphAuthProxy implements HugeGraph {
             String username = currentUsername();
             HugeUser user = this.authManager.getUser(updatedUser.id());
             if (!user.name().equals(username)) {
+                E.checkArgument(HugeAuthenticator.USER_ADMIN.equals(username),
+                                "Only the user themselves or the admin can change this user",
+                                user.name());
                 this.updateCreator(updatedUser);
-                verifyUserPermission(HugePermission.WRITE, user);
             }
             this.invalidRoleCache();
             return this.authManager.updateUser(updatedUser);
@@ -1266,7 +1521,8 @@ public final class HugeGraphAuthProxy implements HugeGraph {
             HugeUser user = this.authManager.getUser(id);
             E.checkArgument(!HugeAuthenticator.USER_ADMIN.equals(user.name()),
                             "Can't delete user '%s'", user.name());
-            verifyUserPermission(HugePermission.DELETE, user);
+            E.checkArgument(HugeAuthenticator.USER_ADMIN.equals(currentUsername()),
+                            "only admin can delete user", user.name());
             HugeGraphAuthProxy.this.auditLimiters.invalidate(user.id());
             this.invalidRoleCache();
             return this.authManager.deleteUser(id);
@@ -1275,10 +1531,6 @@ public final class HugeGraphAuthProxy implements HugeGraph {
         @Override
         public HugeUser findUser(String name) {
             HugeUser user = this.authManager.findUser(name);
-            String username = currentUsername();
-            if (!user.name().equals(username)) {
-                verifyUserPermission(HugePermission.READ, user);
-            }
             return user;
         }
 
@@ -1307,7 +1559,6 @@ public final class HugeGraphAuthProxy implements HugeGraph {
         @Override
         public Id createGroup(HugeGroup group) {
             this.updateCreator(group);
-            verifyUserPermission(HugePermission.WRITE, group);
             this.invalidRoleCache();
             return this.authManager.createGroup(group);
         }
@@ -1315,35 +1566,29 @@ public final class HugeGraphAuthProxy implements HugeGraph {
         @Override
         public Id updateGroup(HugeGroup group) {
             this.updateCreator(group);
-            verifyUserPermission(HugePermission.WRITE, group);
             this.invalidRoleCache();
             return this.authManager.updateGroup(group);
         }
 
         @Override
         public HugeGroup deleteGroup(Id id) {
-            verifyUserPermission(HugePermission.DELETE,
-                                 this.authManager.getGroup(id));
             this.invalidRoleCache();
             return this.authManager.deleteGroup(id);
         }
 
         @Override
         public HugeGroup getGroup(Id id) {
-            return verifyUserPermission(HugePermission.READ,
-                                        this.authManager.getGroup(id));
+            return this.authManager.getGroup(id);
         }
 
         @Override
         public List<HugeGroup> listGroups(List<Id> ids) {
-            return verifyUserPermission(HugePermission.READ,
-                                        this.authManager.listGroups(ids));
+            return this.authManager.listGroups(ids);
         }
 
         @Override
         public List<HugeGroup> listAllGroups(long limit) {
-            return verifyUserPermission(HugePermission.READ,
-                                        this.authManager.listAllGroups(limit));
+            return this.authManager.listAllGroups(limit);
         }
 
         @Override
@@ -1621,9 +1866,124 @@ public final class HugeGraphAuthProxy implements HugeGraph {
         }
 
         @Override
-        public String loginUser(String username, String password) {
+        public Id createSpaceManager(String graphSpace, String owner) {
+            // Set context before calling V2 AuthManager
+            String username = currentUsername();
+            if (username != null) {
+                TaskManager.setContext(
+                        String.format("{\"username\":\"%s\"}", username));
+            }
             try {
-                return this.authManager.loginUser(username, password);
+                return this.authManager.createSpaceManager(graphSpace, owner);
+            } finally {
+                if (username != null) {
+                    TaskManager.resetContext();
+                }
+            }
+        }
+
+        @Override
+        public void deleteSpaceManager(String graphSpace, String owner) {
+            this.authManager.deleteSpaceManager(graphSpace, owner);
+            this.invalidRoleCache();
+        }
+
+        @Override
+        public List<String> listSpaceManager(String graphSpace) {
+            return this.authManager.listSpaceManager(graphSpace);
+        }
+
+        @Override
+        public boolean isSpaceManager(String owner) {
+            return this.authManager.isSpaceManager(owner);
+        }
+
+        @Override
+        public boolean isSpaceManager(String graphSpace, String owner) {
+            return this.authManager.isSpaceManager(graphSpace, owner);
+        }
+
+        @Override
+        public Id createSpaceMember(String graphSpace, String user) {
+            // Set context before calling V2 AuthManager
+            String username = currentUsername();
+            if (username != null) {
+                TaskManager.setContext(
+                        String.format("{\"username\":\"%s\"}", username));
+            }
+            try {
+                return this.authManager.createSpaceMember(graphSpace, user);
+            } finally {
+                if (username != null) {
+                    TaskManager.resetContext();
+                }
+            }
+        }
+
+        @Override
+        public void deleteSpaceMember(String graphSpace, String user) {
+            this.authManager.deleteSpaceMember(graphSpace, user);
+            this.invalidRoleCache();
+        }
+
+        @Override
+        public List<String> listSpaceMember(String graphSpace) {
+            return this.authManager.listSpaceMember(graphSpace);
+        }
+
+        @Override
+        public boolean isSpaceMember(String graphSpace, String user) {
+            return this.authManager.isSpaceMember(graphSpace, user);
+        }
+
+        @Override
+        public Id createAdminManager(String user) {
+            // Set context before calling V2 AuthManager
+            String username = currentUsername();
+            if (username != null) {
+                TaskManager.setContext(
+                        String.format("{\"username\":\"%s\"}", username));
+            }
+            try {
+                return this.authManager.createAdminManager(user);
+            } finally {
+                if (username != null) {
+                    TaskManager.resetContext();
+                }
+            }
+        }
+
+        @Override
+        public void deleteAdminManager(String user) {
+            this.authManager.deleteAdminManager(user);
+            this.invalidRoleCache();
+        }
+
+        @Override
+        public List<String> listAdminManager() {
+            return this.authManager.listAdminManager();
+        }
+
+        @Override
+        public boolean isAdminManager(String user) {
+            return this.authManager.isAdminManager(user);
+        }
+
+        @Override
+        public HugeGroup findGroup(String name) {
+            return this.authManager.findGroup(name);
+        }
+
+        @Override
+        public String loginUser(String username, String password) {
+            return this.loginUser(username, password, -1L);
+        }
+
+        // TODO: the expire haven't been implemented yet
+        @Override
+        public String loginUser(String username, String password, long expire) {
+            try {
+                return this.authManager.loginUser(username, password, expire);
             } catch (AuthenticationException e) {
                 throw new NotAuthorizedException(e.getMessage(), e);
             }
@@ -1841,95 +2201,4 @@ public final class HugeGraphAuthProxy implements HugeGraph {
             return this.origin.toString();
         }
     }
-
-    private static final ThreadLocal<Context> CONTEXTS = new InheritableThreadLocal<>();
-
-    protected static Context setContext(Context context) {
-        Context old = CONTEXTS.get();
-        CONTEXTS.set(context);
-        return old;
-    }
-
-    protected static void resetContext() {
-        CONTEXTS.remove();
-    }
-
-    protected static Context getContext() {
-        // Return task context first
-        String taskContext = TaskManager.getContext();
-        User user = User.fromJson(taskContext);
-        if (user != null) {
-            return new Context(user);
-        }
-
-        return CONTEXTS.get();
-    }
-
-    protected static String getContextString() {
-        Context context = getContext();
-        if (context == null) {
-            return null;
-        }
-        return context.user().toJson();
-    }
-
-    protected static void logUser(User user, String path) {
-        LOG.info("User '{}' login from client [{}] with path '{}'",
-                 user.username(), user.client(), path);
-    }
-
-    static class Context {
-
-        private static final Context ADMIN = new Context(User.ADMIN);
-
-        private final User user;
-
-        public Context(User user) {
-            E.checkNotNull(user, "user");
-            this.user = user;
-        }
-
-        public User user() {
-            return this.user;
-        }
-
-        public static Context admin() {
-            return ADMIN;
-        }
-    }
-
-    static class ContextTask implements Runnable {
-
-        private final Runnable runner;
-        private final Context context;
-
-        public ContextTask(Runnable runner) {
-            this.context = getContext();
-            this.runner = runner;
-        }
-
-        @Override
-        public void run() {
-            setContext(this.context);
-            try {
-                this.runner.run();
-            } finally {
-                resetContext();
-            }
-        }
-    }
-
-    public static class ContextThreadPoolExecutor extends ThreadPoolExecutor {
-
-        public ContextThreadPoolExecutor(int corePoolSize, int maxPoolSize,
-                                         ThreadFactory threadFactory) {
-            super(corePoolSize, maxPoolSize, 0L, TimeUnit.MILLISECONDS,
-                  new LinkedBlockingQueue<>(), threadFactory);
-        }
-
-        @Override
-        public void execute(Runnable command) {
-            super.execute(new ContextTask(command));
-        }
-    }
 }
