@@ -17,18 +17,23 @@
 
 package org.apache.hugegraph;
 
+import java.util.Arrays;
 import java.util.Collection;
+import java.util.Date;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
+import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.Future;
 import java.util.concurrent.TimeoutException;
 import java.util.concurrent.atomic.AtomicInteger;
 
+import org.apache.commons.lang3.StringUtils;
 import org.apache.hugegraph.analyzer.Analyzer;
 import org.apache.hugegraph.analyzer.AnalyzerFactory;
 import org.apache.hugegraph.auth.AuthManager;
 import org.apache.hugegraph.auth.StandardAuthManager;
+import org.apache.hugegraph.auth.StandardAuthManagerV2;
 import org.apache.hugegraph.backend.BackendException;
 import org.apache.hugegraph.backend.LocalCounter;
 import org.apache.hugegraph.backend.cache.Cache;
@@ -62,6 +67,7 @@ import org.apache.hugegraph.event.EventListener;
 import org.apache.hugegraph.exception.NotAllowException;
 import org.apache.hugegraph.io.HugeGraphIoRegistry;
 import org.apache.hugegraph.job.EphemeralJob;
+import org.apache.hugegraph.kvstore.KvStore;
 import org.apache.hugegraph.masterelection.ClusterRoleStore;
 import org.apache.hugegraph.masterelection.Config;
 import org.apache.hugegraph.masterelection.GlobalMasterInfo;
@@ -70,6 +76,8 @@ import org.apache.hugegraph.masterelection.RoleElectionOptions;
 import org.apache.hugegraph.masterelection.RoleElectionStateMachine;
 import org.apache.hugegraph.masterelection.StandardClusterRoleStore;
 import org.apache.hugegraph.masterelection.StandardRoleElectionStateMachine;
+import org.apache.hugegraph.memory.MemoryManager;
+import org.apache.hugegraph.memory.util.RoundUtil;
 import org.apache.hugegraph.meta.MetaManager;
 import org.apache.hugegraph.perf.PerfUtil.Watched;
 import org.apache.hugegraph.rpc.RpcServiceConfig4Client;
@@ -142,47 +150,51 @@ public class StandardHugeGraph implements HugeGraph {
             CoreOptions.VERTEX_DEFAULT_LABEL,
             CoreOptions.VERTEX_ENCODE_PK_NUMBER,
             CoreOptions.STORE_GRAPH,
-            CoreOptions.STORE
+            CoreOptions.STORE,
+            CoreOptions.TASK_RETRY,
+            CoreOptions.OLTP_QUERY_BATCH_SIZE,
+            CoreOptions.OLTP_QUERY_BATCH_AVG_DEGREE_RATIO,
+            CoreOptions.OLTP_QUERY_BATCH_EXPECT_DEGREE,
+            CoreOptions.SCHEMA_INDEX_REBUILD_USING_PUSHDOWN,
+            CoreOptions.QUERY_TRUST_INDEX,
+            CoreOptions.QUERY_MAX_INDEXES_AVAILABLE,
+            CoreOptions.QUERY_DEDUP_OPTION
     );
 
     private static final Logger LOG = Log.logger(StandardHugeGraph.class);
-
+    private final String name;
+    private final StandardHugeGraphParams params;
+    private final HugeConfig configuration;
+    private final EventHub schemaEventHub;
+    private final EventHub graphEventHub;
+    private final EventHub indexEventHub;
+    private final LocalCounter localCounter;
+    private final RateLimiter writeRateLimiter;
+    private final RateLimiter readRateLimiter;
+    private final TaskManager taskManager;
+    private final HugeFeatures features;
+    private final BackendStoreProvider storeProvider;
+    private final TinkerPopTransaction tx;
+    private final RamTable ramtable;
+    private final String schedulerType;
     private volatile boolean started;
     private volatile boolean closed;
     private volatile GraphMode mode;
     private volatile GraphReadMode readMode;
     private volatile HugeVariables variables;
-
-    private final String name;
-
-    private final StandardHugeGraphParams params;
-
-    private final HugeConfig configuration;
-
-    private final EventHub schemaEventHub;
-    private final EventHub graphEventHub;
-    private final EventHub indexEventHub;
-
-    private final LocalCounter localCounter;
-    private final RateLimiter writeRateLimiter;
-    private final RateLimiter readRateLimiter;
-    private final TaskManager taskManager;
+    private String graphSpace;
     private AuthManager authManager;
-
     private RoleElectionStateMachine roleElectionStateMachine;
-
-    private final HugeFeatures features;
-
-    private final BackendStoreProvider storeProvider;
-    private final TinkerPopTransaction tx;
-
-    private final RamTable ramtable;
-
-    private final String schedulerType;
+    private String nickname;
+    private String creator;
+    private Date createTime;
+    private Date updateTime;
+    private KvStore kvStore;
 
     public StandardHugeGraph(HugeConfig config) {
         this.params = new StandardHugeGraphParams();
         this.configuration = config;
+        this.graphSpace = config.get(CoreOptions.GRAPH_SPACE);
 
         this.schemaEventHub = new EventHub("schema");
         this.graphEventHub = new EventHub("graph");
@@ -197,6 +209,11 @@ public class StandardHugeGraph implements HugeGraph {
         this.readRateLimiter = readLimit > 0 ?
                                RateLimiter.create(readLimit) : null;
 
+        String graphSpace = config.getString("graphSpace");
+        if (!StringUtils.isEmpty(graphSpace) && StringUtils.isEmpty(this.graphSpace())) {
+            this.graphSpace(graphSpace);
+        }
+
         boolean ramtableEnable = config.get(CoreOptions.QUERY_RAMTABLE_ENABLE);
         if (ramtableEnable) {
             long vc = config.get(CoreOptions.QUERY_RAMTABLE_VERTICES_CAPACITY);
@@ -207,7 +224,6 @@ public class StandardHugeGraph implements HugeGraph {
         }
 
         this.taskManager = TaskManager.instance();
-
         this.name = config.get(CoreOptions.STORE);
         this.started = false;
         this.closed = false;
@@ -215,15 +231,22 @@ public class StandardHugeGraph implements HugeGraph {
         this.readMode = GraphReadMode.OLTP_ONLY;
         this.schedulerType = config.get(CoreOptions.SCHEDULER_TYPE);
 
-        LockUtil.init(this.name);
+        LockUtil.init(this.spaceGraphName());
+
+        MemoryManager.setMemoryMode(
+                MemoryManager.MemoryMode.fromValue(config.get(CoreOptions.MEMORY_MODE)));
+        MemoryManager.setMaxMemoryCapacityInBytes(config.get(CoreOptions.MAX_MEMORY_CAPACITY));
+        MemoryManager.setMaxMemoryCapacityForOneQuery(
+                config.get(CoreOptions.ONE_QUERY_MAX_MEMORY_CAPACITY));
+        RoundUtil.setAlignment(config.get(CoreOptions.MEMORY_ALIGNMENT));
 
         try {
             this.storeProvider = this.loadStoreProvider();
         } catch (Exception e) {
-            LockUtil.destroy(this.name);
+            LockUtil.destroy(this.spaceGraphName());
             String message = "Failed to load backend store provider";
             LOG.error("{}: {}", message, e.getMessage());
-            throw new HugeException(message, e);
+            throw new HugeException(message);
         }
 
         if (isHstore()) {
@@ -241,20 +264,47 @@ public class StandardHugeGraph implements HugeGraph {
             SnowflakeIdGenerator.init(this.params);
 
             this.taskManager.addScheduler(this.params);
-            this.authManager = new StandardAuthManager(this.params);
+            if (isHstore()) {
+                this.authManager = new StandardAuthManagerV2((this.params));
+            } else {
+                this.authManager = new StandardAuthManager(this.params);
+            }
             this.variables = null;
         } catch (Exception e) {
             this.storeProvider.close();
-            LockUtil.destroy(this.name);
+            LockUtil.destroy(this.spaceGraphName());
             throw e;
         }
     }
 
+    @Override
+    public BackendStoreProvider storeProvider() {
+        return this.storeProvider;
+    }
+
+    @Override
+    public String graphSpace() {
+        return this.graphSpace;
+    }
+
+    @Override
+    public void graphSpace(String graphSpace) {
+        this.graphSpace = graphSpace;
+    }
+
     @Override
     public String name() {
         return this.name;
     }
 
+    @Override
+    public String spaceGraphName() {
+        if (this.graphSpace == null) {
+            return this.name;
+        }
+        return this.graphSpace + "-" + this.name;
+    }
+
     @Override
     public HugeGraph hugegraph() {
         return this;
@@ -265,7 +315,6 @@ public class StandardHugeGraph implements HugeGraph {
         return this.storeProvider.type();
     }
 
-    @Override
     public BackendStoreInfo backendStoreInfo() {
         // Just for trigger Tx.getOrNewTransaction, then load 3 stores
         // TODO: pass storeProvider.metaStore()
@@ -280,24 +329,24 @@ public class StandardHugeGraph implements HugeGraph {
 
     @Override
     public void serverStarted(GlobalMasterInfo nodeInfo) {
-        LOG.info("Init system info for graph '{}'", this.name);
+        LOG.info("Init system info for graph '{}'", this.spaceGraphName());
         this.initSystemInfo();
 
         LOG.info("Init server info [{}-{}] for graph '{}'...",
-                 nodeInfo.nodeId(), nodeInfo.nodeRole(), this.name);
+                 nodeInfo.nodeId(), nodeInfo.nodeRole(), this.spaceGraphName());
         this.serverInfoManager().initServerInfo(nodeInfo);
 
         this.initRoleStateMachine(nodeInfo.nodeId());
 
         // TODO: check necessary?
-        LOG.info("Check olap property-key tables for graph '{}'", this.name);
+        LOG.info("Check olap property-key tables for graph '{}'", this.spaceGraphName());
         for (PropertyKey pk : this.schemaTransaction().getPropertyKeys()) {
             if (pk.olap()) {
                 this.graphTransaction().initAndRegisterOlapTable(pk.id());
             }
         }
 
-        LOG.info("Restoring incomplete tasks for graph '{}'...", this.name);
+        LOG.info("Restoring incomplete tasks for graph '{}'...", this.spaceGraphName());
         this.taskScheduler().restoreTasks();
 
         this.started = true;
@@ -324,6 +373,11 @@ public class StandardHugeGraph implements HugeGraph {
         return this.started;
     }
 
+    @Override
+    public synchronized void started(boolean started) {
+        this.started = started;
+    }
+
     @Override
     public boolean closed() {
         if (this.closed && !this.tx.closed()) {
@@ -332,6 +386,16 @@ public class StandardHugeGraph implements HugeGraph {
         return this.closed;
     }
 
+    private void closeTx() {
+        try {
+            if (this.tx.isOpen()) {
+                this.tx.close();
+            }
+        } finally {
+            this.tx.destroyTransaction();
+        }
+    }
+
     @Override
     public GraphMode mode() {
         return this.mode;
@@ -361,13 +425,59 @@ public class StandardHugeGraph implements HugeGraph {
         this.storeProvider.waitReady(rpcServer);
     }
 
+    @Override
+    public String nickname() {
+        return this.nickname;
+    }
+
+    @Override
+    public void nickname(String nickname) {
+        this.nickname = nickname;
+    }
+
+    @Override
+    public String creator() {
+        return this.creator;
+    }
+
+    @Override
+    public void creator(String creator) {
+        this.creator = creator;
+    }
+
+    @Override
+    public Date createTime() {
+        return this.createTime;
+    }
+
+    @Override
+    public void createTime(Date createTime) {
+        this.createTime = createTime;
+    }
+
+    @Override
+    public Date updateTime() {
+        return this.updateTime;
+    }
+
+    @Override
+    public void updateTime(Date updateTime) {
+        this.updateTime = updateTime;
+    }
+
+    public void waitStarted() {
+        // Just for trigger Tx.getOrNewTransaction, then load 3 stores
+        this.schemaTransaction();
+        //this.storeProvider.waitStoreStarted();
+    }
+
     @Override
     public void initBackend() {
         this.loadSchemaStore().open(this.configuration);
         this.loadSystemStore().open(this.configuration);
         this.loadGraphStore().open(this.configuration);
 
-        LockUtil.lock(this.name, LockUtil.GRAPH_LOCK);
+        LockUtil.lock(this.spaceGraphName(), LockUtil.GRAPH_LOCK);
         try {
             this.storeProvider.init();
             /*
@@ -377,13 +487,13 @@ public class StandardHugeGraph implements HugeGraph {
              */
             this.initSystemInfo();
         } finally {
-            LockUtil.unlock(this.name, LockUtil.GRAPH_LOCK);
+            LockUtil.unlock(this.spaceGraphName(), LockUtil.GRAPH_LOCK);
             this.loadGraphStore().close();
             this.loadSystemStore().close();
             this.loadSchemaStore().close();
         }
 
-        LOG.info("Graph '{}' has been initialized", this.name);
+        LOG.info("Graph '{}' has been initialized", this.spaceGraphName());
     }
 
     @Override
@@ -394,33 +504,43 @@ public class StandardHugeGraph implements HugeGraph {
         this.loadSystemStore().open(this.configuration);
         this.loadGraphStore().open(this.configuration);
 
-        LockUtil.lock(this.name, LockUtil.GRAPH_LOCK);
+        LockUtil.lock(this.spaceGraphName(), LockUtil.GRAPH_LOCK);
         try {
             this.storeProvider.clear();
         } finally {
-            LockUtil.unlock(this.name, LockUtil.GRAPH_LOCK);
+            LockUtil.unlock(this.spaceGraphName(), LockUtil.GRAPH_LOCK);
             this.loadGraphStore().close();
             this.loadSystemStore().close();
             this.loadSchemaStore().close();
         }
 
-        LOG.info("Graph '{}' has been cleared", this.name);
+        LOG.info("Graph '{}' has been cleared", this.spaceGraphName());
     }
 
     @Override
     public void truncateBackend() {
         this.waitUntilAllTasksCompleted();
 
-        LockUtil.lock(this.name, LockUtil.GRAPH_LOCK);
+        LockUtil.lock(this.spaceGraphName(), LockUtil.GRAPH_LOCK);
         try {
             this.storeProvider.truncate();
             // TODO: remove this after serverinfo saved in etcd
             this.serverStarted(this.serverInfoManager().globalNodeRoleInfo());
         } finally {
-            LockUtil.unlock(this.name, LockUtil.GRAPH_LOCK);
+            LockUtil.unlock(this.spaceGraphName(), LockUtil.GRAPH_LOCK);
         }
 
-        LOG.info("Graph '{}' has been truncated", this.name);
+        LOG.info("Graph '{}' has been truncated", this.spaceGraphName());
+    }
+
+    @Override
+    public void kvStore(KvStore kvStore) {
+        this.kvStore = kvStore;
+    }
+
+    @Override
+    public KvStore kvStore() {
+        return this.kvStore;
     }
 
     @Override
@@ -437,24 +557,24 @@ public class StandardHugeGraph implements HugeGraph {
 
     @Override
     public void createSnapshot() {
-        LockUtil.lock(this.name, LockUtil.GRAPH_LOCK);
+        LockUtil.lock(this.spaceGraphName(), LockUtil.GRAPH_LOCK);
         try {
             this.storeProvider.createSnapshot();
         } finally {
-            LockUtil.unlock(this.name, LockUtil.GRAPH_LOCK);
+            LockUtil.unlock(this.spaceGraphName(), LockUtil.GRAPH_LOCK);
         }
-        LOG.info("Graph '{}' has created snapshot", this.name);
+        LOG.info("Graph '{}' has created snapshot", this.spaceGraphName());
     }
 
     @Override
     public void resumeSnapshot() {
-        LockUtil.lock(this.name, LockUtil.GRAPH_LOCK);
+        LockUtil.lock(this.spaceGraphName(), LockUtil.GRAPH_LOCK);
         try {
             this.storeProvider.resumeSnapshot();
         } finally {
-            LockUtil.unlock(this.name, LockUtil.GRAPH_LOCK);
+            LockUtil.unlock(this.spaceGraphName(), LockUtil.GRAPH_LOCK);
         }
-        LOG.info("Graph '{}' has resumed from snapshot", this.name);
+        LOG.info("Graph '{}' has resumed from snapshot", this.spaceGraphName());
     }
 
     private void clearVertexCache() {
@@ -477,8 +597,8 @@ public class StandardHugeGraph implements HugeGraph {
         try {
             if (isHstore()) {
                 return new CachedSchemaTransactionV2(
-                    MetaManager.instance().metaDriver(),
-                    MetaManager.instance().cluster(), this.params);
+                        MetaManager.instance().metaDriver(),
+                        MetaManager.instance().cluster(), this.params);
             }
             return new CachedSchemaTransaction(this.params, loadSchemaStore());
         } catch (BackendException e) {
@@ -530,16 +650,6 @@ public class StandardHugeGraph implements HugeGraph {
         return this.storeProvider.loadSystemStore(this.configuration);
     }
 
-    @Watched
-    private ISchemaTransaction schemaTransaction() {
-        this.checkGraphNotClosed();
-        /*
-         * NOTE: each schema operation will be auto committed,
-         * Don't need to open tinkerpop tx by readWrite() and commit manually.
-         */
-        return this.tx.schemaTransaction();
-    }
-
     private SysTransaction systemTransaction() {
         this.checkGraphNotClosed();
         /*
@@ -567,19 +677,15 @@ public class StandardHugeGraph implements HugeGraph {
 
     private AbstractSerializer serializer() {
         String name = this.configuration.get(CoreOptions.SERIALIZER);
-        LOG.debug("Loading serializer '{}' for graph '{}'", name, this.name);
-        AbstractSerializer serializer = SerializerFactory.serializer(this.configuration, name);
-        if (serializer == null) {
-            throw new HugeException("Can't load serializer with name " + name);
-        }
-        return serializer;
+        LOG.debug("Loading serializer '{}' for graph '{}'", name, this.spaceGraphName());
+        return SerializerFactory.serializer(this.configuration, name);
     }
 
     private Analyzer analyzer() {
         String name = this.configuration.get(CoreOptions.TEXT_ANALYZER);
         String mode = this.configuration.get(CoreOptions.TEXT_ANALYZER_MODE);
         LOG.debug("Loading text analyzer '{}' with mode '{}' for graph '{}'",
-                  name, mode, this.name);
+                  name, mode, this.spaceGraphName());
         return AnalyzerFactory.analyzer(name, mode);
     }
 
@@ -588,9 +694,9 @@ public class StandardHugeGraph implements HugeGraph {
     }
 
     protected void reloadRamtable(boolean loadFromFile) {
-        // Expect triggered manually, like gremlin job
+        // Expect triggered manually, like a gremlin job
         if (this.ramtable != null) {
-            this.ramtable.reload(loadFromFile, this.name);
+            this.ramtable.reload(loadFromFile, this.spaceGraphName());
         } else {
             LOG.warn("The ramtable feature is not enabled for graph {}", this);
         }
@@ -758,7 +864,7 @@ public class StandardHugeGraph implements HugeGraph {
 
     @Override
     public Id addPropertyKey(PropertyKey pkey) {
-        assert this.name.equals(pkey.graph().name());
+        assert this.spaceGraphName().equals(pkey.graph().spaceGraphName());
         if (pkey.olap()) {
             this.clearVertexCache();
         }
@@ -767,7 +873,7 @@ public class StandardHugeGraph implements HugeGraph {
 
     @Override
     public void updatePropertyKey(PropertyKey pkey) {
-        assert this.name.equals(pkey.graph().name());
+        assert this.spaceGraphName().equals(pkey.graph().spaceGraphName());
         this.schemaTransaction().updatePropertyKey(pkey);
     }
 
@@ -814,13 +920,13 @@ public class StandardHugeGraph implements HugeGraph {
 
     @Override
     public void addVertexLabel(VertexLabel label) {
-        assert this.name.equals(label.graph().name());
+        assert this.spaceGraphName().equals(label.graph().spaceGraphName());
         this.schemaTransaction().addVertexLabel(label);
     }
 
     @Override
     public void updateVertexLabel(VertexLabel label) {
-        assert this.name.equals(label.graph().name());
+        assert this.spaceGraphName().equals(label.graph().spaceGraphName());
         this.schemaTransaction().updateVertexLabel(label);
     }
 
@@ -876,13 +982,13 @@ public class StandardHugeGraph implements HugeGraph {
 
     @Override
     public void addEdgeLabel(EdgeLabel label) {
-        assert this.name.equals(label.graph().name());
+        assert this.spaceGraphName().equals(label.graph().spaceGraphName());
         this.schemaTransaction().addEdgeLabel(label);
     }
 
     @Override
     public void updateEdgeLabel(EdgeLabel label) {
-        assert this.name.equals(label.graph().name());
+        assert this.spaceGraphName().equals(label.graph().spaceGraphName());
         this.schemaTransaction().updateEdgeLabel(label);
     }
 
@@ -927,14 +1033,14 @@ public class StandardHugeGraph implements HugeGraph {
     @Override
     public void addIndexLabel(SchemaLabel schemaLabel, IndexLabel indexLabel) {
         assert VertexLabel.OLAP_VL.equals(schemaLabel) ||
-               this.name.equals(schemaLabel.graph().name());
-        assert this.name.equals(indexLabel.graph().name());
+               this.spaceGraphName().equals(schemaLabel.graph().spaceGraphName());
+        assert this.spaceGraphName().equals(indexLabel.graph().spaceGraphName());
         this.schemaTransaction().addIndexLabel(schemaLabel, indexLabel);
     }
 
     @Override
     public void updateIndexLabel(IndexLabel label) {
-        assert this.name.equals(label.graph().name());
+        assert this.spaceGraphName().equals(label.graph().spaceGraphName());
         this.schemaTransaction().updateIndexLabel(label);
     }
 
@@ -993,12 +1099,19 @@ public class StandardHugeGraph implements HugeGraph {
         } finally {
             this.closed = true;
             this.storeProvider.close();
-            LockUtil.destroy(this.name);
+            LockUtil.destroy(this.spaceGraphName());
         }
+
         // Make sure that all transactions are closed in all threads
+        if (!this.tx.closed()) {
+            for (String key : this.tx.openedThreads) {
+                LOG.warn("thread [{}] did not close transaction", key);
+            }
+        }
         E.checkState(this.tx.closed(),
                      "Ensure tx closed in all threads when closing graph '%s'",
-                     this.name);
+                     this.spaceGraphName());
+
     }
 
     @Override
@@ -1007,7 +1120,7 @@ public class StandardHugeGraph implements HugeGraph {
         this.serverStarted(nodeInfo);
 
         // Write config to the disk file
-        String confPath = ConfigUtil.writeToFile(configPath, this.name(),
+        String confPath = ConfigUtil.writeToFile(configPath, this.name,
                                                  this.configuration());
         this.configuration.file(confPath);
     }
@@ -1041,6 +1154,15 @@ public class StandardHugeGraph implements HugeGraph {
         return config;
     }
 
+    public void clearSchedulerAndLock() {
+        this.taskManager.forceRemoveScheduler(this.params);
+        try {
+            LockUtil.destroy(this.spaceGraphName());
+        } catch (Exception e) {
+            // Ignore
+        }
+    }
+
     @Override
     public HugeFeatures features() {
         return this.features;
@@ -1061,6 +1183,15 @@ public class StandardHugeGraph implements HugeGraph {
         return new SchemaManager(this.schemaTransaction(), this);
     }
 
+    public ISchemaTransaction schemaTransaction() {
+        this.checkGraphNotClosed();
+        /*
+         * NOTE: each schema operation will be auto committed,
+         * Don't need to open tinkerpop tx by readWrite() and commit manually.
+         */
+        return this.tx.schemaTransaction();
+    }
+
     @Override
     public Id getNextId(HugeType type) {
         return this.schemaTransaction().getNextId(type);
@@ -1119,7 +1250,7 @@ public class StandardHugeGraph implements HugeGraph {
 
     @Override
     public String toString() {
-        return StringFactory.graphString(this, this.name());
+        return StringFactory.graphString(this, this.spaceGraphName());
     }
 
     @Override
@@ -1160,26 +1291,16 @@ public class StandardHugeGraph implements HugeGraph {
 
         Class<GraphCacheNotifier> clazz1 = GraphCacheNotifier.class;
         // The proxy is sometimes unavailable (issue #664)
-        CacheNotifier proxy = clientConfig.serviceProxy(this.name, clazz1);
-        serverConfig.addService(this.name, clazz1, new HugeGraphCacheNotifier(
+        CacheNotifier proxy = clientConfig.serviceProxy(this.spaceGraphName(), clazz1);
+        serverConfig.addService(this.spaceGraphName(), clazz1, new HugeGraphCacheNotifier(
                 this.graphEventHub, proxy));
 
         Class<SchemaCacheNotifier> clazz2 = SchemaCacheNotifier.class;
-        proxy = clientConfig.serviceProxy(this.name, clazz2);
-        serverConfig.addService(this.name, clazz2, new HugeSchemaCacheNotifier(
+        proxy = clientConfig.serviceProxy(this.spaceGraphName(), clazz2);
+        serverConfig.addService(this.spaceGraphName(), clazz2, new HugeSchemaCacheNotifier(
                 this.schemaEventHub, proxy));
     }
 
-    private void closeTx() {
-        try {
-            if (this.tx.isOpen()) {
-                this.tx.close();
-            }
-        } finally {
-            this.tx.destroyTransaction();
-        }
-    }
-
     private void waitUntilAllTasksCompleted() {
         long timeout = this.configuration.get(CoreOptions.TASK_WAIT_TIMEOUT);
         try {
@@ -1189,10 +1310,172 @@ public class StandardHugeGraph implements HugeGraph {
         }
     }
 
+    private static final class Txs {
+
+        private final ISchemaTransaction schemaTx;
+        private final SysTransaction systemTx;
+        private final GraphTransaction graphTx;
+        private long openedTime;
+
+        public Txs(ISchemaTransaction schemaTx, SysTransaction systemTx,
+                   GraphTransaction graphTx) {
+            assert schemaTx != null && systemTx != null && graphTx != null;
+            this.schemaTx = schemaTx;
+            this.systemTx = systemTx;
+            this.graphTx = graphTx;
+            this.openedTime = DateUtil.now().getTime();
+        }
+
+        public void commit() {
+            this.graphTx.commit();
+        }
+
+        public void rollback() {
+            this.graphTx.rollback();
+        }
+
+        public void close() {
+            try {
+                this.graphTx.close();
+            } catch (Exception e) {
+                LOG.error("Failed to close GraphTransaction", e);
+            }
+
+            try {
+                this.systemTx.close();
+            } catch (Exception e) {
+                LOG.error("Failed to close SystemTransaction", e);
+            }
+
+            try {
+                this.schemaTx.close();
+            } catch (Exception e) {
+                LOG.error("Failed to close SchemaTransaction", e);
+            }
+        }
+
+        public void openedTime(long time) {
+            this.openedTime = time;
+        }
+
+        public long openedTime() {
+            return this.openedTime;
+        }
+
+        @Override
+        public String toString() {
+            return String.format("{schemaTx=%s,systemTx=%s,graphTx=%s}",
+                                 this.schemaTx, this.systemTx, this.graphTx);
+        }
+    }
+
+    private static class SysTransaction extends GraphTransaction {
+
+        public SysTransaction(HugeGraphParams graph, BackendStore store) {
+            super(graph, store);
+            this.autoCommit(true);
+        }
+    }
+
+    private static class AbstractCacheNotifier implements CacheNotifier {
+
+        public static final Logger LOG = Log.logger(AbstractCacheNotifier.class);
+
+        private final EventHub hub;
+        private final EventListener cacheEventListener;
+
+        public AbstractCacheNotifier(EventHub hub, CacheNotifier proxy) {
+            this.hub = hub;
+            this.cacheEventListener = event -> {
+                try {
+                    LOG.info("Received event: {}", event);
+                    Object[] args = event.args();
+                    E.checkArgument(args.length > 0 && args[0] instanceof String,
+                                    "Expect event action argument");
+                    String action = (String) args[0];
+                    LOG.debug("Event action: {}", action);
+                    if (Cache.ACTION_INVALIDED.equals(action)) {
+                        event.checkArgs(String.class, HugeType.class, Object.class);
+                        HugeType type = (HugeType) args[1];
+                        Object ids = args[2];
+                        if (ids instanceof Id[]) {
+                            LOG.debug("Calling proxy.invalid2 with type: {}, IDs: {}", type,
+                                      Arrays.toString((Id[]) ids));
+                            proxy.invalid2(type, (Id[]) ids);
+                        } else if (ids instanceof Id) {
+                            LOG.debug("Calling proxy.invalid with type: {}, ID: {}", type, ids);
+                            proxy.invalid(type, (Id) ids);
+                        } else {
+                            LOG.error("Unexpected argument: {}", ids);
+                            E.checkArgument(false, "Unexpected argument: %s", ids);
+                        }
+                        return true;
+                    } else if (Cache.ACTION_CLEARED.equals(action)) {
+                        event.checkArgs(String.class, HugeType.class);
+                        HugeType type = (HugeType) args[1];
+                        LOG.debug("Calling proxy.clear with type: {}", type);
+                        proxy.clear(type);
+                        return true;
+                    }
+                } catch (Exception e) {
+                    LOG.error("Error processing cache event: {}", e.getMessage(), e);
+                }
+                LOG.warn("Event {} not handled", event);
+                return false;
+            };
+            this.hub.listen(Events.CACHE, this.cacheEventListener);
+            LOG.info("Cache event listener registered successfully. cacheEventListener {}",
+                     this.cacheEventListener);
+        }
+
+        @Override
+        public void close() {
+            this.hub.unlisten(Events.CACHE, this.cacheEventListener);
+        }
+
+        @Override
+        public void invalid(HugeType type, Id id) {
+            this.hub.notify(Events.CACHE, Cache.ACTION_INVALID, type, id);
+        }
+
+        @Override
+        public void invalid2(HugeType type, Object[] ids) {
+            this.hub.notify(Events.CACHE, Cache.ACTION_INVALID, type, ids);
+        }
+
+        @Override
+        public void clear(HugeType type) {
+            this.hub.notify(Events.CACHE, Cache.ACTION_CLEAR, type);
+        }
+
+        @Override
+        public void reload() {
+            // pass
+        }
+    }
+
+    private static class HugeSchemaCacheNotifier
+            extends AbstractCacheNotifier
+            implements SchemaCacheNotifier {
+
+        public HugeSchemaCacheNotifier(EventHub hub, CacheNotifier proxy) {
+            super(hub, proxy);
+        }
+    }
+
+    private static class HugeGraphCacheNotifier
+            extends AbstractCacheNotifier
+            implements GraphCacheNotifier {
+
+        public HugeGraphCacheNotifier(EventHub hub, CacheNotifier proxy) {
+            super(hub, proxy);
+        }
+    }
+
     private class StandardHugeGraphParams implements HugeGraphParams {
 
-        private HugeGraph graph = StandardHugeGraph.this;
         private final EphemeralJobQueue ephemeralJobQueue = new EphemeralJobQueue(this);
+        private HugeGraph graph = StandardHugeGraph.this;
 
         private void graph(HugeGraph graph) {
             this.graph = graph;
@@ -1208,6 +1491,11 @@ public class StandardHugeGraph implements HugeGraph {
             return StandardHugeGraph.this.name();
         }
 
+        @Override
+        public String spaceGraphName() {
+            return StandardHugeGraph.this.spaceGraphName();
+        }
+
         @Override
         public GraphMode mode() {
             return StandardHugeGraph.this.mode();
@@ -1301,7 +1589,6 @@ public class StandardHugeGraph implements HugeGraph {
 
         @Override
         public ServerInfoManager serverManager() {
-            // this.serverManager.initSchemaIfNeeded();
             return StandardHugeGraph.this.serverInfoManager();
         }
 
@@ -1350,6 +1637,8 @@ public class StandardHugeGraph implements HugeGraph {
 
         // Times opened from the upper layer
         private final AtomicInteger refs;
+        private final ConcurrentHashMap.KeySetView<String, Boolean> openedThreads =
+                ConcurrentHashMap.newKeySet();
         // Flag opened of each thread
         private final ThreadLocal<Boolean> opened;
         // Backend transactions
@@ -1464,6 +1753,7 @@ public class StandardHugeGraph implements HugeGraph {
             assert !this.opened.get();
             this.opened.set(true);
             this.transactions.get().openedTime(DateUtil.now().getTime());
+            this.openedThreads.add(Thread.currentThread().getName());
             this.refs.incrementAndGet();
         }
 
@@ -1471,6 +1761,7 @@ public class StandardHugeGraph implements HugeGraph {
             // Just set flag opened=false to reuse the backend tx
             if (this.opened.get()) {
                 this.opened.set(false);
+                this.openedThreads.remove(Thread.currentThread().getName());
                 this.refs.decrementAndGet();
             }
         }
@@ -1536,150 +1827,4 @@ public class StandardHugeGraph implements HugeGraph {
             this.transactions.remove();
         }
     }
-
-    private static final class Txs {
-
-        private final ISchemaTransaction schemaTx;
-        private final SysTransaction systemTx;
-        private final GraphTransaction graphTx;
-        private long openedTime;
-
-        public Txs(ISchemaTransaction schemaTx, SysTransaction systemTx,
-                   GraphTransaction graphTx) {
-            assert schemaTx != null && systemTx != null && graphTx != null;
-            this.schemaTx = schemaTx;
-            this.systemTx = systemTx;
-            this.graphTx = graphTx;
-            this.openedTime = DateUtil.now().getTime();
-        }
-
-        public void commit() {
-            this.graphTx.commit();
-        }
-
-        public void rollback() {
-            this.graphTx.rollback();
-        }
-
-        public void close() {
-            try {
-                this.graphTx.close();
-            } catch (Exception e) {
-                LOG.error("Failed to close GraphTransaction", e);
-            }
-
-            try {
-                this.systemTx.close();
-            } catch (Exception e) {
-                LOG.error("Failed to close SystemTransaction", e);
-            }
-
-            try {
-                this.schemaTx.close();
-            } catch (Exception e) {
-                LOG.error("Failed to close SchemaTransaction", e);
-            }
-        }
-
-        public void openedTime(long time) {
-            this.openedTime = time;
-        }
-
-        public long openedTime() {
-            return this.openedTime;
-        }
-
-        @Override
-        public String toString() {
-            return String.format("{schemaTx=%s,systemTx=%s,graphTx=%s}",
-                                 this.schemaTx, this.systemTx, this.graphTx);
-        }
-    }
-
-    private static class SysTransaction extends GraphTransaction {
-
-        public SysTransaction(HugeGraphParams graph, BackendStore store) {
-            super(graph, store);
-            this.autoCommit(true);
-        }
-    }
-
-    private static class AbstractCacheNotifier implements CacheNotifier {
-
-        private final EventHub hub;
-        private final EventListener cacheEventListener;
-
-        public AbstractCacheNotifier(EventHub hub, CacheNotifier proxy) {
-            this.hub = hub;
-            this.cacheEventListener = event -> {
-                Object[] args = event.args();
-                E.checkArgument(args.length > 0 && args[0] instanceof String,
-                                "Expect event action argument");
-                if (Cache.ACTION_INVALIDED.equals(args[0])) {
-                    event.checkArgs(String.class, HugeType.class, Object.class);
-                    HugeType type = (HugeType) args[1];
-                    Object ids = args[2];
-                    if (ids instanceof Id[]) {
-                        // argument type mismatch: proxy.invalid2(type,Id[]ids)
-                        proxy.invalid2(type, (Id[]) ids);
-                    } else if (ids instanceof Id) {
-                        proxy.invalid(type, (Id) ids);
-                    } else {
-                        E.checkArgument(false, "Unexpected argument: %s", ids);
-                    }
-                    return true;
-                } else if (Cache.ACTION_CLEARED.equals(args[0])) {
-                    event.checkArgs(String.class, HugeType.class);
-                    HugeType type = (HugeType) args[1];
-                    proxy.clear(type);
-                    return true;
-                }
-                return false;
-            };
-            this.hub.listen(Events.CACHE, this.cacheEventListener);
-        }
-
-        @Override
-        public void close() {
-            this.hub.unlisten(Events.CACHE, this.cacheEventListener);
-        }
-
-        @Override
-        public void invalid(HugeType type, Id id) {
-            this.hub.notify(Events.CACHE, Cache.ACTION_INVALID, type, id);
-        }
-
-        @Override
-        public void invalid2(HugeType type, Object[] ids) {
-            this.hub.notify(Events.CACHE, Cache.ACTION_INVALID, type, ids);
-        }
-
-        @Override
-        public void clear(HugeType type) {
-            this.hub.notify(Events.CACHE, Cache.ACTION_CLEAR, type);
-        }
-
-        @Override
-        public void reload() {
-            // pass
-        }
-    }
-
-    private static class HugeSchemaCacheNotifier
-            extends AbstractCacheNotifier
-            implements SchemaCacheNotifier {
-
-        public HugeSchemaCacheNotifier(EventHub hub, CacheNotifier proxy) {
-            super(hub, proxy);
-        }
-    }
-
-    private static class HugeGraphCacheNotifier
-            extends AbstractCacheNotifier
-            implements GraphCacheNotifier {
-
-        public HugeGraphCacheNotifier(EventHub hub, CacheNotifier proxy) {
-            super(hub, proxy);
-        }
-    }
 }
