@@ -57,7 +57,10 @@ public class HugeProject extends Entity {
     }
 
     public HugeProject(String name, String description) {
-        this(null, name, description, null, null, null, null);
+        this(StringUtils.isNotEmpty(name) ? IdGenerator.of(name) : null, name, description, null,
+             null,
+             null,
+             null);
     }
 
     public HugeProject(Id id, String name, String description, Id adminGroupId,
@@ -234,6 +237,11 @@ public class HugeProject extends Entity {
         return fromVertex(vertex, target);
     }
 
+    public static HugeProject fromMap(Map<String, Object> map) {
+        HugeProject project = new HugeProject("");
+        return fromMap(map, project);
+    }
+
     @Override
     public String name() {
         return this.name;
