@@ -22,9 +22,11 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
+import org.apache.commons.lang3.StringUtils;
 import org.apache.hugegraph.HugeGraphParams;
 import org.apache.hugegraph.auth.SchemaDefine.Entity;
 import org.apache.hugegraph.backend.id.Id;
+import org.apache.hugegraph.backend.id.IdGenerator;
 import org.apache.hugegraph.schema.VertexLabel;
 import org.apache.hugegraph.util.E;
 import org.apache.tinkerpop.gremlin.structure.Graph.Hidden;
@@ -46,7 +48,7 @@ public class HugeUser extends Entity {
     private RolePermission role;
 
     public HugeUser(String name) {
-        this(null, name);
+        this(StringUtils.isNotEmpty(name) ? IdGenerator.of(name) : null, name);
     }
 
     public HugeUser(Id id) {
@@ -156,6 +158,9 @@ public class HugeUser extends Entity {
             case P.AVATAR:
                 this.avatar = (String) value;
                 break;
+            case P.DESCRIPTION:
+                this.description = (String) value;
+                break;
             default:
                 throw new AssertionError("Unsupported key: " + key);
         }
@@ -193,6 +198,11 @@ public class HugeUser extends Entity {
             list.add(this.avatar);
         }
 
+        if (this.description != null) {
+            list.add(P.DESCRIPTION);
+            list.add(this.description);
+        }
+
         return super.asArray(list);
     }
 
@@ -218,6 +228,10 @@ public class HugeUser extends Entity {
             map.put(Hidden.unHide(P.AVATAR), this.avatar);
         }
 
+        if (this.description != null) {
+            map.put(Hidden.unHide(P.DESCRIPTION), this.description);
+        }
+
         return super.asMap(map);
     }
 
@@ -233,6 +247,7 @@ public class HugeUser extends Entity {
     public static final class P {
 
         public static final String USER = Hidden.hide("user");
+        public static final String USER_HIDDEN = USER;
 
         public static final String ID = T.id.getAccessor();
         public static final String LABEL = T.label.getAccessor();
@@ -242,6 +257,7 @@ public class HugeUser extends Entity {
         public static final String PHONE = "~user_phone";
         public static final String EMAIL = "~user_email";
         public static final String AVATAR = "~user_avatar";
+        public static final String DESCRIPTION = "~user_description";
 
         public static String unhide(String key) {
             final String prefix = Hidden.hide("user_");
@@ -271,7 +287,7 @@ public class HugeUser extends Entity {
                                     .properties(properties)
                                     .usePrimaryKeyId()
                                     .primaryKeys(P.NAME)
-                                    .nullableKeys(P.PHONE, P.EMAIL, P.AVATAR)
+                                    .nullableKeys(P.PHONE, P.EMAIL, P.AVATAR, P.DESCRIPTION)
                                     .enableLabelIndex(true)
                                     .build();
             this.graph.schemaTransaction().addVertexLabel(label);
@@ -285,6 +301,7 @@ public class HugeUser extends Entity {
             props.add(createPropertyKey(P.PHONE));
             props.add(createPropertyKey(P.EMAIL));
             props.add(createPropertyKey(P.AVATAR));
+            props.add(createPropertyKey(P.DESCRIPTION));
 
             return super.initProperties(props);
         }
