@@ -20,6 +20,7 @@ package org.apache.hugegraph.auth;
 import java.time.Duration;
 import java.util.ArrayList;
 import java.util.HashSet;
+import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -46,7 +47,6 @@ import org.apache.hugegraph.util.Log;
 import org.apache.hugegraph.util.StringEncoding;
 import org.slf4j.Logger;
 
-import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableMap;
 
 import io.jsonwebtoken.Claims;
@@ -76,6 +76,8 @@ public class StandardAuthManager implements AuthManager {
     private final TokenGenerator tokenGenerator;
     private final long tokenExpire;
 
+    private final String defaultGraphSpace = "DEFAULT";
+
     private Set<String> ipWhiteList;
 
     private Boolean ipWhiteListEnabled;
@@ -114,9 +116,18 @@ public class StandardAuthManager implements AuthManager {
         this.ipWhiteListEnabled = false;
     }
 
+    /**
+     * Maybe can define an proxy class to choose forward or call local
+     */
+    public static boolean isLocal(AuthManager authManager) {
+        return authManager instanceof StandardAuthManager ||
+               //FIXME: The judgment of v2 is best placed in the islocal of v2
+               authManager instanceof StandardAuthManagerV2;
+    }
+
     private <V> Cache<Id, V> cache(String prefix, long capacity,
                                    long expiredTime) {
-        String name = prefix + "-" + this.graph.name();
+        String name = prefix + "-" + this.graph.spaceGraphName();
         Cache<Id, V> cache = CacheManager.instance().cache(name, capacity);
         if (expiredTime > 0L) {
             cache.expire(Duration.ofSeconds(expiredTime).toMillis());
@@ -400,10 +411,16 @@ public class StandardAuthManager implements AuthManager {
             HugeResource resource = new HugeResource(ResourceType.PROJECT,
                                                      project.name(),
                                                      null);
+            //FIXME: project api
+            Map<String, List<HugeResource>> defaultResources = new LinkedHashMap<>();
+            List<HugeResource> resources = new ArrayList<>();
+            resources.add(resource);
+            defaultResources.put(defaultGraphSpace, resources);
+
             HugeTarget target = new HugeTarget(targetName,
                                                this.graph.name(),
                                                "localhost:8080",
-                                               ImmutableList.of(resource));
+                                               defaultResources);
             // Ditto
             target.creator(project.creator());
             Id targetId = this.targets.add(target);
@@ -435,7 +452,7 @@ public class StandardAuthManager implements AuthManager {
     @Override
     public HugeProject deleteProject(Id id) {
         return this.commit(() -> {
-            LockUtil.Locks locks = new LockUtil.Locks(this.graph.name());
+            LockUtil.Locks locks = new LockUtil.Locks(this.graph.spaceGraphName());
             try {
                 locks.lockWrites(LockUtil.PROJECT_UPDATE, id);
 
@@ -491,7 +508,7 @@ public class StandardAuthManager implements AuthManager {
                         "Failed to add graphs to project '%s', the graphs " +
                         "parameter can't be empty", id);
 
-        LockUtil.Locks locks = new LockUtil.Locks(this.graph.name());
+        LockUtil.Locks locks = new LockUtil.Locks(this.graph.spaceGraphName());
         try {
             locks.lockWrites(LockUtil.PROJECT_UPDATE, id);
 
@@ -519,7 +536,7 @@ public class StandardAuthManager implements AuthManager {
                         "Failed to delete graphs from the project '%s', " +
                         "the graphs parameter can't be null or empty", id);
 
-        LockUtil.Locks locks = new LockUtil.Locks(this.graph.name());
+        LockUtil.Locks locks = new LockUtil.Locks(this.graph.spaceGraphName());
         try {
             locks.lockWrites(LockUtil.PROJECT_UPDATE, id);
 
@@ -604,6 +621,7 @@ public class StandardAuthManager implements AuthManager {
         // Collect accesses by user
         List<HugeAccess> accesses = new ArrayList<>();
         List<HugeBelong> belongs = this.listBelongByUser(user.id(), -1);
+
         for (HugeBelong belong : belongs) {
             accesses.addAll(this.listAccessByGroup(belong.target(), -1));
         }
@@ -636,6 +654,13 @@ public class StandardAuthManager implements AuthManager {
     @Override
     public String loginUser(String username, String password)
             throws AuthenticationException {
+        return this.loginUser(username, password, -1L);
+    }
+
+    // TODO: the expire haven't been implemented yet
+    @Override
+    public String loginUser(String username, String password, long expire)
+            throws AuthenticationException {
         HugeUser user = this.matchUser(username, password);
         if (user == null) {
             String msg = "Incorrect username or password";
@@ -717,11 +742,74 @@ public class StandardAuthManager implements AuthManager {
         this.ipWhiteListEnabled = status;
     }
 
-    /**
-     * Maybe can define an proxy class to choose forward or call local
-     */
-    public static boolean isLocal(AuthManager authManager) {
-        return authManager instanceof StandardAuthManager;
+    @Override
+    public Id createSpaceManager(String graphSpace, String owner) {
+        return null;
+    }
+
+    @Override
+    public void deleteSpaceManager(String graphSpace, String owner) {
+
+    }
+
+    @Override
+    public List<String> listSpaceManager(String graphSpace) {
+        return List.of();
+    }
+
+    @Override
+    public boolean isSpaceManager(String owner) {
+        return false;
+    }
+
+    @Override
+    public boolean isSpaceManager(String graphSpace, String owner) {
+        return false;
+    }
+
+    @Override
+    public Id createSpaceMember(String graphSpace, String user) {
+        return null;
+    }
+
+    @Override
+    public void deleteSpaceMember(String graphSpace, String user) {
+
+    }
+
+    @Override
+    public List<String> listSpaceMember(String graphSpace) {
+        return List.of();
+    }
+
+    @Override
+    public boolean isSpaceMember(String graphSpace, String user) {
+        return false;
+    }
+
+    @Override
+    public Id createAdminManager(String user) {
+        return null;
+    }
+
+    @Override
+    public void deleteAdminManager(String user) {
+
+    }
+
+    @Override
+    public List<String> listAdminManager() {
+        return List.of();
+    }
+
+    @Override
+    public boolean isAdminManager(String user) {
+        return false;
+    }
+
+    @Override
+    public HugeGroup findGroup(String name) {
+        return null;
     }
 
     public <R> R commit(Callable<R> callable) {
