@@ -150,4 +150,8 @@ public class CacheManager {
                         "Invalid cache implement: %s", cache.getClass());
         return cache;
     }
+
+    public void clearCache() {
+        this.caches.clear();
+    }
 }
