@@ -67,8 +67,7 @@ public interface Id extends Comparable<Id> {
         }
 
         public static IdType valueOfPrefix(String id) {
-            E.checkArgument(id != null && !id.isEmpty(),
-                            "Invalid id '%s'", id);
+            E.checkArgument(id != null && !id.isEmpty(), "Invalid id '%s'", id);
             switch (id.charAt(0)) {
                 case 'L':
                     return IdType.LONG;
