@@ -23,6 +23,7 @@ import java.util.UUID;
 import org.apache.hugegraph.backend.id.Id.IdType;
 import org.apache.hugegraph.backend.serializer.BytesBuffer;
 import org.apache.hugegraph.structure.HugeVertex;
+import org.apache.hugegraph.util.Bytes;
 import org.apache.hugegraph.util.E;
 import org.apache.hugegraph.util.LongEncoding;
 import org.apache.hugegraph.util.NumericUtil;
@@ -119,23 +120,29 @@ public abstract class IdGenerator {
         return IdType.UNKNOWN;
     }
 
-    private static int compareType(Id id1, Id id2) {
+    public static int compareType(Id id1, Id id2) {
         return idType(id1).ordinal() - idType(id2).ordinal();
     }
 
     /****************************** id defines ******************************/
 
-    public static final class StringId implements Id {
+    public static class StringId implements Id {
 
-        private final String id;
+        protected String id;
+        protected byte[] bytes;
 
         public StringId(String id) {
-            E.checkArgument(!id.isEmpty(), "The id can't be empty");
+            E.checkArgument(id != null && !id.isEmpty(),
+                            "The id can't be null or empty");
             this.id = id;
+            this.bytes = null;
         }
 
         public StringId(byte[] bytes) {
-            this.id = StringEncoding.decode(bytes);
+            E.checkArgument(bytes != null && bytes.length > 0,
+                            "The id bytes can't be null or empty");
+            this.bytes = bytes;
+            this.id = null;
         }
 
         @Override
@@ -145,27 +152,35 @@ public abstract class IdGenerator {
 
         @Override
         public Object asObject() {
-            return this.id;
+            return this.asString();
         }
 
         @Override
         public String asString() {
+            if (this.id == null) {
+                assert this.bytes != null;
+                this.id = StringEncoding.decode(this.bytes);
+            }
             return this.id;
         }
 
         @Override
         public long asLong() {
-            return Long.parseLong(this.id);
+            return Long.parseLong(this.asString());
         }
 
         @Override
         public byte[] asBytes() {
-            return StringEncoding.encode(this.id);
+            if (this.bytes == null) {
+                assert this.id != null;
+                this.bytes = StringEncoding.encode(this.id);
+            }
+            return this.bytes;
         }
 
         @Override
         public int length() {
-            return this.id.length();
+            return this.asString().length();
         }
 
         @Override
@@ -174,33 +189,45 @@ public abstract class IdGenerator {
             if (cmp != 0) {
                 return cmp;
             }
-            return this.id.compareTo(other.asString());
+            if (this.id != null) {
+                return this.id.compareTo(other.asString());
+            } else {
+                return Bytes.compare(this.bytes, other.asBytes());
+            }
         }
 
         @Override
         public int hashCode() {
-            return this.id.hashCode();
+            return this.asString().hashCode();
         }
 
         @Override
-        public boolean equals(Object other) {
-            if (!(other instanceof StringId)) {
+        public boolean equals(Object obj) {
+            if (!(obj instanceof StringId)) {
                 return false;
             }
-            return this.id.equals(((StringId) other).id);
+            StringId other = (StringId) obj;
+            if (this.id != null) {
+                return this.id.equals(other.asString());
+            } else if (other.bytes == null) {
+                return this.asString().equals(other.asString());
+            } else {
+                assert this.bytes != null;
+                return Bytes.equals(this.bytes, other.asBytes());
+            }
         }
 
         @Override
         public String toString() {
-            return this.id;
+            return this.asString();
         }
     }
 
-    public static final class LongId extends Number implements Id {
+    public static class LongId extends Number implements Id {
 
         private static final long serialVersionUID = -7732461469037400190L;
 
-        private final long id;
+        protected Long id;
 
         public LongId(long id) {
             this.id = id;
@@ -270,7 +297,7 @@ public abstract class IdGenerator {
 
         @Override
         public int intValue() {
-            return (int) this.id;
+            return this.id.intValue();
         }
 
         @Override
@@ -289,9 +316,9 @@ public abstract class IdGenerator {
         }
     }
 
-    public static final class UuidId implements Id {
+    public static class UuidId implements Id {
 
-        private final UUID uuid;
+        protected UUID uuid;
 
         public UuidId(String string) {
             this(StringEncoding.uuid(string));
@@ -379,9 +406,9 @@ public abstract class IdGenerator {
     /**
      * This class is just used by backend store for wrapper object as Id
      */
-    public static final class ObjectId implements Id {
+    public static class ObjectId implements Id {
 
-        private final Object object;
+        protected Object object;
 
         public ObjectId(Object object) {
             E.checkNotNull(object, "object");
