@@ -39,6 +39,7 @@ import org.apache.hugegraph.backend.query.IdRangeQuery;
 import org.apache.hugegraph.backend.query.Query;
 import org.apache.hugegraph.backend.store.BackendEntry;
 import org.apache.hugegraph.config.HugeConfig;
+import org.apache.hugegraph.iterator.CIter;
 import org.apache.hugegraph.schema.EdgeLabel;
 import org.apache.hugegraph.schema.IndexLabel;
 import org.apache.hugegraph.schema.PropertyKey;
@@ -65,6 +66,7 @@ import org.apache.hugegraph.type.define.SchemaStatus;
 import org.apache.hugegraph.type.define.WriteType;
 import org.apache.hugegraph.util.E;
 import org.apache.hugegraph.util.JsonUtil;
+import org.apache.tinkerpop.gremlin.structure.Edge;
 
 import com.google.common.collect.ImmutableMap;
 
@@ -221,11 +223,12 @@ public class TextSerializer extends AbstractSerializer {
 
         HugeGraph graph = vertex.graph();
         boolean direction = colParts[0].equals(EDGE_OUT_TYPE);
-        String sortValues = readEdgeName(colParts[2]);
+        String sortValues = readEdgeName(colParts[3]);
         EdgeLabel edgeLabel = graph.edgeLabelOrNone(readId(colParts[1]));
-        Id otherVertexId = readEntryId(colParts[3]);
+        EdgeLabel subEdgeLabel = graph.edgeLabelOrNone(readId(colParts[2]));
+        Id otherVertexId = readEntryId(colParts[4]);
         // Construct edge
-        HugeEdge edge = HugeEdge.constructEdge(vertex, direction, edgeLabel,
+        HugeEdge edge = HugeEdge.constructEdge(vertex, direction, subEdgeLabel,
                                                sortValues, otherVertexId);
 
         String[] valParts = colValue.split(VALUE_SPLITOR);
@@ -352,6 +355,13 @@ public class TextSerializer extends AbstractSerializer {
         throw new NotImplementedException("Unsupported readEdge()");
     }
 
+    @Override
+    public CIter<Edge> readEdges(HugeGraph graph, BackendEntry bytesEntry) {
+        E.checkNotNull(graph, "serializer graph");
+        // TODO: implement
+        throw new NotImplementedException("Unsupported readEdges()");
+    }
+
     @Override
     public BackendEntry writeIndex(HugeIndex index) {
         TextBackendEntry entry = newBackendEntry(index.type(), index.id());
@@ -763,6 +773,7 @@ public class TextSerializer extends AbstractSerializer {
         // Edge name: type + edge-label-name + sortKeys + targetVertex
         list.add(writeType(edgeId.direction().type()));
         list.add(writeId(edgeId.edgeLabelId()));
+        list.add(writeId(edgeId.subLabelId()));
         list.add(writeEdgeName(edgeId.sortValues()));
         list.add(writeEntryId(edgeId.otherVertexId()));
 
