@@ -94,7 +94,7 @@ public abstract class BackendEntryIterator implements CIter<BackendEntry> {
 
     public static final void checkInterrupted() {
         if (Thread.interrupted()) {
-            throw new BackendException("Interrupted, maybe it is timed out",
+            throw new BackendException("Interrupted, maybe it is timed out or uses too much memory",
                                        new InterruptedException());
         }
     }
