@@ -31,6 +31,14 @@ public interface BackendFeatures {
         return false;
     }
 
+    default boolean supportsTaskAndServerVertex() {
+        return false;
+    }
+
+    default boolean supportsFatherAndSubEdgeLabel() {
+        return true;
+    }
+
     boolean supportsScanToken();
 
     boolean supportsScanKeyPrefix();
