@@ -22,6 +22,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.function.Function;
 
+import org.apache.hugegraph.HugeGraph;
 import org.apache.hugegraph.backend.BackendException;
 import org.apache.hugegraph.backend.query.Query;
 import org.apache.hugegraph.backend.store.BackendEntry;
@@ -152,6 +153,13 @@ public class RaftBackendStore implements BackendStore {
                 this.queryByRaft(query, o -> this.store.query(query));
     }
 
+    @Override
+    public Iterator<Iterator<BackendEntry>> query(Iterator<Query> queries,
+                                                  Function<Query, Query> queryWriter,
+                                                  HugeGraph hugeGraph) {
+        throw new UnsupportedOperationException("unimplemented for RaftBackendStore");
+    }
+
     @Override
     public Number queryNumber(Query query) {
         return (Number)
