@@ -67,8 +67,7 @@ public class ServerInfoManager {
     private volatile boolean onlySingleNode;
     private volatile boolean closed;
 
-    public ServerInfoManager(HugeGraphParams graph,
-                             ExecutorService dbExecutor) {
+    public ServerInfoManager(HugeGraphParams graph, ExecutorService dbExecutor) {
         E.checkNotNull(graph, "graph");
         E.checkNotNull(dbExecutor, "db executor");
 
@@ -107,9 +106,20 @@ public class ServerInfoManager {
 
         Id serverId = nodeInfo.nodeId();
         HugeServerInfo existed = this.serverInfo(serverId);
+        if (existed != null && existed.alive()) {
+            final long now = DateUtil.now().getTime();
+            if (existed.expireTime() > now + 30 * 1000) {
+                LOG.info("The node time maybe skew very much: {}", existed);
+                throw new HugeException("The server with name '%s' maybe skew very much", serverId);
+            }
+            try {
+                Thread.sleep(existed.expireTime() - now + 1);
+            } catch (InterruptedException e) {
+               throw new HugeException("Interrupted when waiting for server info expired", e);
+            }
+        }
         E.checkArgument(existed == null || !existed.alive(),
-                        "The server with name '%s' already in cluster",
-                        serverId);
+                        "The server with name '%s' already in cluster", serverId);
 
         if (nodeInfo.nodeRole().master()) {
             String page = this.supportsPaging() ? PageInfo.PAGE_NONE : null;
@@ -185,13 +195,12 @@ public class ServerInfoManager {
         /* ServerInfo is missing */
         if (this.selfNodeId() == null) {
             // Ignore if ServerInfo is not initialized
-            LOG.info("ServerInfo is missing: {}, may not be initialized yet");
+            LOG.info("ServerInfo is missing: {}, may not be initialized yet", this.selfNodeId());
             return;
         }
         if (this.selfIsMaster()) {
-            // On master node, just wait for ServerInfo re-init
-            LOG.warn("ServerInfo is missing: {}, may be cleared before",
-                     this.selfNodeId());
+            // On the master node, just wait for ServerInfo re-init
+            LOG.warn("ServerInfo is missing: {}, may be cleared before", this.selfNodeId());
             return;
         }
         /*
@@ -232,12 +241,10 @@ public class ServerInfoManager {
             if (!server.alive()) {
                 continue;
             }
-
             if (server.role().master()) {
                 master = server;
                 continue;
             }
-
             hasWorkerNode = true;
             if (!server.suitableFor(task, now)) {
                 continue;
@@ -254,13 +261,12 @@ public class ServerInfoManager {
             this.onlySingleNode = singleNode;
         }
 
-        // Only schedule to master if there is no workers and master is suitable
+        // Only schedule to master if there are no workers and master are suitable
         if (!hasWorkerNode) {
             if (master != null && master.suitableFor(task, now)) {
                 serverWithMinLoad = master;
             }
         }
-
         return serverWithMinLoad;
     }
 
@@ -286,8 +292,7 @@ public class ServerInfoManager {
                 throw new HugeException("Schema is missing for %s '%s'",
                                         HugeServerInfo.P.SERVER, serverInfo);
             }
-            HugeVertex vertex = this.tx().constructVertex(false,
-                                                          serverInfo.asArray());
+            HugeVertex vertex = this.tx().constructVertex(false, serverInfo.asArray());
             // Add or update server info in backend store
             vertex = this.tx().addVertex(vertex);
             return vertex.id();
@@ -301,8 +306,7 @@ public class ServerInfoManager {
             }
             HugeServerInfo.Schema schema = HugeServerInfo.schema(this.graph);
             if (!schema.existVertexLabel(HugeServerInfo.P.SERVER)) {
-                throw new HugeException("Schema is missing for %s",
-                                        HugeServerInfo.P.SERVER);
+                throw new HugeException("Schema is missing for %s", HugeServerInfo.P.SERVER);
             }
             // Save server info in batch
             GraphTransaction tx = this.tx();
@@ -346,7 +350,7 @@ public class ServerInfoManager {
 
     private HugeServerInfo serverInfo(Id serverId) {
         return this.call(() -> {
-            Iterator<Vertex> vertices = this.tx().queryVertices(serverId);
+            Iterator<Vertex> vertices = this.tx().queryServerInfos(serverId);
             Vertex vertex = QueryResults.one(vertices);
             if (vertex == null) {
                 return null;
@@ -374,7 +378,7 @@ public class ServerInfoManager {
         }
         LOG.info("Remove server info: {}", serverId);
         return this.call(() -> {
-            Iterator<Vertex> vertices = this.tx().queryVertices(serverId);
+            Iterator<Vertex> vertices = this.tx().queryServerInfos(serverId);
             Vertex vertex = QueryResults.one(vertices);
             if (vertex == null) {
                 return null;
@@ -409,7 +413,12 @@ public class ServerInfoManager {
     private Iterator<HugeServerInfo> serverInfos(Map<String, Object> conditions,
                                                  long limit, String page) {
         return this.call(() -> {
-            ConditionQuery query = new ConditionQuery(HugeType.VERTEX);
+            ConditionQuery query;
+            if (this.graph.backendStoreFeatures().supportsTaskAndServerVertex()) {
+                query = new ConditionQuery(HugeType.SERVER);
+            } else {
+                query = new ConditionQuery(HugeType.VERTEX);
+            }
             if (page != null) {
                 query.page(page);
             }
@@ -425,7 +434,7 @@ public class ServerInfoManager {
             if (limit != NO_LIMIT) {
                 query.limit(limit);
             }
-            Iterator<Vertex> vertices = this.tx().queryVertices(query);
+            Iterator<Vertex> vertices = this.tx().queryServerInfos(query);
             Iterator<HugeServerInfo> servers =
                     new MapperIterator<>(vertices, HugeServerInfo::fromVertex);
             // Convert iterator to list to avoid across thread tx accessed
