@@ -91,6 +91,16 @@ public class StandardTaskScheduler implements TaskScheduler {
         this.taskTx = null;
     }
 
+    private static boolean sleep(long ms) {
+        try {
+            Thread.sleep(ms);
+            return true;
+        } catch (InterruptedException ignored) {
+            // Ignore InterruptedException
+            return false;
+        }
+    }
+
     @Override
     public HugeGraph graph() {
         return this.graph.graph();
@@ -101,6 +111,11 @@ public class StandardTaskScheduler implements TaskScheduler {
         return this.graph.name();
     }
 
+    @Override
+    public String spaceGraphName() {
+        return this.graph.spaceGraphName();
+    }
+
     @Override
     public int pendingTasks() {
         return this.tasks.size();
@@ -154,6 +169,11 @@ public class StandardTaskScheduler implements TaskScheduler {
             LOG.info("restore task {}", task);
             this.restore(task);
         }
+        try {
+            this.graph.graphTransaction().commit();
+        } finally {
+            this.graph.closeTx();
+        }
     }
 
     private <V> Future<?> restore(HugeTask<V> task) {
@@ -193,7 +213,6 @@ public class StandardTaskScheduler implements TaskScheduler {
 
         // Check this is on master for normal task schedule
         this.checkOnMasterNode("schedule");
-
         if (this.serverManager().onlySingleNode() && !task.computer()) {
             /*
              * Speed up for single node, submit the task immediately,
@@ -517,7 +536,7 @@ public class StandardTaskScheduler implements TaskScheduler {
     }
 
     public <V> HugeTask<V> findTask(Id id) {
-        HugeTask<V> result =  this.call(() -> {
+        HugeTask<V> result = this.call(() -> {
             Iterator<Vertex> vertices = this.tx().queryTaskInfos(id);
             Vertex vertex = QueryResults.one(vertices);
             if (vertex == null) {
@@ -728,14 +747,4 @@ public class StandardTaskScheduler implements TaskScheduler {
     private boolean supportsPaging() {
         return this.graph.backendStoreFeatures().supportsQueryByPage();
     }
-
-    private static boolean sleep(long ms) {
-        try {
-            Thread.sleep(ms);
-            return true;
-        } catch (InterruptedException ignored) {
-            // Ignore InterruptedException
-            return false;
-        }
-    }
 }
