@@ -23,7 +23,7 @@ REPORT_FILE=$REPORT_DIR/jacoco-api-test.xml
 
 TRAVIS_DIR=$(dirname $0)
 VERSION=$(mvn help:evaluate -Dexpression=project.version -q -DforceStdout)
-SERVER_DIR=hugegraph-server/apache-hugegraph-incubating-$VERSION
+SERVER_DIR=hugegraph-server/apache-hugegraph-server-incubating-$VERSION
 RAFT1_DIR=hugegraph-raft1
 RAFT2_DIR=hugegraph-raft2
 RAFT3_DIR=hugegraph-raft3
@@ -35,7 +35,7 @@ JACOCO_PORT=36320
 RAFT_TOOLS=$RAFT1_DIR/bin/raft-tools.sh
 RAFT_LEADER="127.0.0.1:8091"
 
-mvn package -DskipTests
+mvn package -Dmaven.test.skip=true
 
 # mkdir for each raft-server
 cp -r $SERVER_DIR $RAFT1_DIR
