@@ -31,15 +31,11 @@ CONF=$BASE_DIR/conf/graphs/hugegraph.properties
 REST_CONF=$BASE_DIR/conf/rest-server.properties
 GREMLIN_CONF=$BASE_DIR/conf/gremlin-server.yaml
 
-. ${BIN}/util.sh
+. "${BIN}"/util.sh
 
 declare -A backend_serializer_map=(["memory"]="text" \
-                                   ["cassandra"]="cassandra" \
-                                   ["scylladb"]="scylladb" \
-                                   ["mysql"]="mysql" \
                                    ["hbase"]="hbase" \
                                    ["rocksdb"]="binary" \
-                                   ["postgresql"]="postgresql" \
                                    ["hstore"]="binary")
 
 SERIALIZER=${backend_serializer_map[$BACKEND]}
@@ -48,11 +44,6 @@ SERIALIZER=${backend_serializer_map[$BACKEND]}
 sed -i "s/backend=.*/backend=$BACKEND/" $CONF
 sed -i "s/serializer=.*/serializer=$SERIALIZER/" $CONF
 
-# Set PostgresSQL configurations if needed
-if [ "$BACKEND" == "postgresql" ]; then
-    sed -i '/org.postgresql.Driver/,+2 s/\#//g' $CONF
-fi
-
 # Set timeout for hbase
 if [ "$BACKEND" == "hbase" ]; then
     sed -i '$arestserver.request_timeout=200' $REST_CONF
@@ -60,6 +51,11 @@ if [ "$BACKEND" == "hbase" ]; then
     sed -i 's/evaluationTimeout.*/evaluationTimeout: 200000/' $GREMLIN_CONF
 fi
 
+# Set usePD=true for hstore
+if [ "$BACKEND" == "hstore" ]; then
+    sed -i '$ausePD=true' $REST_CONF
+fi
+
 # Append schema.sync_deletion=true to config file
 echo "schema.sync_deletion=true" >> $CONF
 
