@@ -44,12 +44,8 @@ public class ExampleUtil {
         }
         registered = true;
 
-        RegisterUtil.registerCassandra();
-        RegisterUtil.registerScyllaDB();
         RegisterUtil.registerHBase();
         RegisterUtil.registerRocksDB();
-        RegisterUtil.registerMysql();
-        RegisterUtil.registerPalo();
     }
 
     public static HugeGraph loadGraph() {
