@@ -1,18 +1,18 @@
 /*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with this
- * work for additional information regarding copyright ownership. The ASF
- * licenses this file to You under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
- * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
- * License for the specific language governing permissions and limitations
- * under the License.
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.hugegraph.backend.store.hbase;
@@ -29,7 +29,6 @@ import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Set;
 import java.util.concurrent.Future;
-import org.apache.hugegraph.util.Log;
 
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.Path;
@@ -68,8 +67,6 @@ import org.apache.hadoop.hbase.filter.PageFilter;
 import org.apache.hadoop.hbase.filter.PrefixFilter;
 import org.apache.hadoop.hbase.util.VersionInfo;
 import org.apache.hadoop.security.UserGroupInformation;
-import org.slf4j.Logger;
-
 import org.apache.hugegraph.backend.BackendException;
 import org.apache.hugegraph.backend.store.BackendEntry.BackendColumn;
 import org.apache.hugegraph.backend.store.BackendEntry.BackendIterator;
@@ -79,8 +76,11 @@ import org.apache.hugegraph.config.HugeConfig;
 import org.apache.hugegraph.exception.NotSupportException;
 import org.apache.hugegraph.util.Bytes;
 import org.apache.hugegraph.util.E;
+import org.apache.hugegraph.util.Log;
 import org.apache.hugegraph.util.StringEncoding;
 import org.apache.hugegraph.util.VersionUtil;
+import org.slf4j.Logger;
+
 import com.google.common.util.concurrent.Futures;
 
 public class HbaseSessions extends BackendSessionPool {
@@ -218,7 +218,7 @@ public class HbaseSessions extends BackendSessionPool {
 
     public void createTable(String table, List<byte[]> cfs) throws IOException {
         TableDescriptorBuilder tdb = TableDescriptorBuilder.newBuilder(
-                                     TableName.valueOf(this.namespace, table));
+                TableName.valueOf(this.namespace, table));
         for (byte[] cf : cfs) {
             tdb.setColumnFamily(ColumnFamilyDescriptorBuilder.newBuilder(cf)
                                                              .build());
@@ -237,7 +237,7 @@ public class HbaseSessions extends BackendSessionPool {
             builder.setColumnFamily(ColumnFamilyDescriptorBuilder.newBuilder(cf).build());
         }
         byte[][] splits = new byte[numOfPartitions - 1]
-                                  [org.apache.hadoop.hbase.util.Bytes.SIZEOF_SHORT];
+                [org.apache.hadoop.hbase.util.Bytes.SIZEOF_SHORT];
         for (short split = 1; split < numOfPartitions; split++) {
             splits[split - 1] = org.apache.hadoop.hbase.util.Bytes.toBytes(split);
         }
@@ -421,7 +421,7 @@ public class HbaseSessions extends BackendSessionPool {
         default R scan(String table, byte[] startRow, boolean inclusiveStart,
                        byte[] prefix) {
             final Scan scan = new Scan();
-            if(startRow == prefix) {
+            if (startRow == prefix) {
                 scan.setRowPrefixFilter(prefix);
             } else {
                 scan.withStartRow(startRow, inclusiveStart)
@@ -465,7 +465,7 @@ public class HbaseSessions extends BackendSessionPool {
      * Session implement for HBase
      */
     public class Session extends AbstractBackendSession
-                         implements HbaseSession<RowIterator> {
+            implements HbaseSession<RowIterator> {
 
         private final Map<String, List<Row>> batch;
 
@@ -491,7 +491,7 @@ public class HbaseSessions extends BackendSessionPool {
         }
 
         private void checkBatchResults(Object[] results, List<Row> rows)
-                                       throws Throwable {
+                throws Throwable {
             assert rows.size() == results.length;
             for (int i = 0; i < results.length; i++) {
                 Object result = results[i];
@@ -534,7 +534,7 @@ public class HbaseSessions extends BackendSessionPool {
          */
         @Override
         public boolean hasChanges() {
-            return this.batch.size() > 0;
+            return !this.batch.isEmpty();
         }
 
         /**
@@ -560,7 +560,7 @@ public class HbaseSessions extends BackendSessionPool {
                 } catch (Throwable e) {
                     // TODO: Mark and delete committed records
                     throw new BackendException("Failed to commit, " +
-                              "there may be inconsistent states for HBase", e);
+                                               "there may be inconsistent states for HBase", e);
                 }
             }
 
