@@ -30,7 +30,7 @@ import jakarta.ws.rs.core.Response;
 
 public class GremlinApiTest extends BaseApiTest {
 
-    private static String path = "/gremlin";
+    private static final String path = "/gremlin";
 
     @Test
     public void testPost() {
@@ -38,14 +38,15 @@ public class GremlinApiTest extends BaseApiTest {
                       "\"gremlin\":\"g.V()\"," +
                       "\"bindings\":{}," +
                       "\"language\":\"gremlin-groovy\"," +
-                      "\"aliases\":{\"g\":\"__g_hugegraph\"}}";
+                      "\"aliases\":{\"g\":\"__g_DEFAULT-hugegraph\"}}";
         assertResponseStatus(200, client().post(path, body));
     }
 
     @Test
     public void testGet() {
         Map<String, Object> params = ImmutableMap.of("gremlin",
-                                                     "hugegraph.traversal().V()");
+                                                     "this.binding.'DEFAULT-hugegraph'.traversal" +
+                                                     "().V()");
         Response r = client().get(path, params);
         Assert.assertEquals(r.readEntity(String.class), 200, r.getStatus());
     }
@@ -56,9 +57,10 @@ public class GremlinApiTest extends BaseApiTest {
                               "\"gremlin\":\"%s\"," +
                               "\"bindings\":{}," +
                               "\"language\":\"gremlin-groovy\"," +
-                              "\"aliases\":{\"g\":\"__g_hugegraph\"}}";
+                              "\"aliases\":{\"graph\":\"DEFAULT-hugegraph\"," +
+                              "\"g\":\"__g_DEFAULT-hugegraph\"}}";
 
-        String script = "schema=hugegraph.schema();" +
+        String script = "schema=graph.schema();" +
                         "schema.propertyKey('name').asText().ifNotExist().create();" +
                         "schema.propertyKey('age').asInt().ifNotExist().create();" +
                         "schema.propertyKey('city').asUUID().ifNotExist().create();" +
@@ -70,10 +72,10 @@ public class GremlinApiTest extends BaseApiTest {
                         "knows=schema.edgeLabel('knows').sourceLabel('person').targetLabel" +
                         "('person')." +
                         "properties('date').ifNotExist().create();" +
-                        "marko=hugegraph.addVertex(T.id,'835e1153928149578691cf79258e90eb'" +
+                        "marko=graph.addVertex(T.id,'835e1153928149578691cf79258e90eb'" +
                         ",T.label,'person','name','marko','age',29," +
                         "'city','135e1153928149578691cf79258e90eb');" +
-                        "vadas=hugegraph.addVertex(T.id,'935e1153928149578691cf79258e90eb'" +
+                        "vadas=graph.addVertex(T.id,'935e1153928149578691cf79258e90eb'" +
                         ",T.label,'person','name','vadas','age',27," +
                         "'city','235e1153928149578691cf79258e90eb');" +
                         "marko.addEdge('knows',vadas,'date','20160110');";
@@ -92,11 +94,12 @@ public class GremlinApiTest extends BaseApiTest {
     @Test
     public void testClearAndInit() {
         String body = "{" +
-                      "\"gremlin\":\"hugegraph.backendStoreFeatures()" +
+                      "\"gremlin\":\"graph.backendStoreFeatures()" +
                       "                       .supportsSharedStorage();\"," +
                       "\"bindings\":{}," +
                       "\"language\":\"gremlin-groovy\"," +
-                      "\"aliases\":{\"g\":\"__g_hugegraph\"}}";
+                      "\"aliases\":{\"graph\":\"DEFAULT-hugegraph\"," +
+                      "\"g\":\"__g_DEFAULT-hugegraph\"}}";
         String content = assertResponseStatus(200, client().post(path, body));
         Map<?, ?> result = assertJsonContains(content, "result");
         @SuppressWarnings({"unchecked"})
@@ -107,42 +110,60 @@ public class GremlinApiTest extends BaseApiTest {
 
         body = "{" +
                "\"gremlin\":\"" +
-               "  if (!hugegraph.backendStoreFeatures()" +
+               "  if (!graph.backendStoreFeatures()" +
                "                .supportsSharedStorage())" +
                "    return;" +
-               "  def auth = hugegraph.hugegraph().authManager();" +
+               "  def auth = graph.hugegraph().authManager();" +
                "  def admin = auth.findUser('admin');" +
-               "  hugegraph.clearBackend();" +
-               "  hugegraph.initBackend();" +
-               "  auth.createUser(admin);\"," +
+               "  graph.clearBackend();" +
+               "  graph.initBackend();" +
+               "  try {" +
+               "    auth.createUser(admin);" +
+               "  } catch(Exception e) {" +
+               "  }" +
+               "\"," +
                "\"bindings\":{}," +
                "\"language\":\"gremlin-groovy\"," +
-               "\"aliases\":{\"g\":\"__g_hugegraph\"}}";
+               "\"aliases\":{\"graph\":\"DEFAULT-hugegraph\"," +
+               "\"g\":\"__g_DEFAULT-hugegraph\"}}";
+
         assertResponseStatus(200, client().post(path, body));
 
         body = "{" +
-               "\"gremlin\":\"hugegraph.serverStarted(" +
+               "\"gremlin\":\"graph.serverStarted(" +
                "              GlobalMasterInfo.master('server1'))\"," +
                "\"bindings\":{}," +
                "\"language\":\"gremlin-groovy\"," +
-               "\"aliases\":{\"g\":\"__g_hugegraph\"}}";
+               "\"aliases\":{\"graph\":\"DEFAULT-hugegraph\"," +
+               "\"g\":\"__g_DEFAULT-hugegraph\"}}";
         assertResponseStatus(200, client().post(path, body));
     }
 
+    //FIXME: non-pd will not delete admin, but pd mode will
     @Test
     public void testTruncate() {
-        String body = "{" +
-                      "\"gremlin\":\"try {hugegraph.truncateBackend()} " +
-                      "catch (UnsupportedOperationException e) {}\"," +
-                      "\"bindings\":{}," +
-                      "\"language\":\"gremlin-groovy\"," +
-                      "\"aliases\":{\"g\":\"__g_hugegraph\"}}";
+        String body = "{"
+                      + "\"gremlin\":\""
+                      + "  def auth = graph.hugegraph().authManager();"
+                      + "  def admin = auth.findUser('admin');"
+                      + "  graph.truncateBackend();"
+                      + "  def after = auth.findUser('admin');"
+                      + "  if (after == null) {"
+                      + "    auth.createUser(admin);"
+                      + "  }"
+                      + "\","
+                      + "\"bindings\":{},"
+                      + "\"language\":\"gremlin-groovy\","
+                      + "\"aliases\":{\"graph\":\"DEFAULT-hugegraph\","
+                      + "\"g\":\"__g_DEFAULT-hugegraph\"}"
+                      + "}";
+
         assertResponseStatus(200, client().post(path, body));
     }
 
     @Test
     public void testSetVertexProperty() {
-        String pkPath = "/graphs/hugegraph/schema/propertykeys/";
+        String pkPath = "/" + URL_PREFIX + "/schema/propertykeys/";
         // Cardinality single
         String foo = "{" +
                      "\"name\": \"foo\"," +
@@ -160,7 +181,7 @@ public class GremlinApiTest extends BaseApiTest {
                      "}";
         assertResponseStatus(202, client().post(pkPath, bar));
 
-        String vlPath = "/graphs/hugegraph/schema/vertexlabels/";
+        String vlPath = "/" + URL_PREFIX + "/schema/vertexlabels/";
         String vertexLabel = "{" +
                              "\"name\": \"person\"," +
                              "\"id_strategy\": \"CUSTOMIZE_STRING\"," +
@@ -174,7 +195,7 @@ public class GremlinApiTest extends BaseApiTest {
                       ".property('foo', '123').property('bar', '123')\"," +
                       "\"bindings\":{}," +
                       "\"language\":\"gremlin-groovy\"," +
-                      "\"aliases\":{\"g\":\"__g_hugegraph\"}}";
+                      "\"aliases\":{\"g\":\"__g_DEFAULT-hugegraph\"}}";
         assertResponseStatus(200, client().post(path, body));
 
         // Supply matched cardinality
@@ -183,7 +204,7 @@ public class GremlinApiTest extends BaseApiTest {
                ".property(list, 'bar', '123')\"," +
                "\"bindings\":{}," +
                "\"language\":\"gremlin-groovy\"," +
-               "\"aliases\":{\"g\":\"__g_hugegraph\"}}";
+               "\"aliases\":{\"g\":\"__g_DEFAULT-hugegraph\"}}";
         assertResponseStatus(200, client().post(path, body));
 
         // Supply unmatch cardinality
@@ -192,7 +213,7 @@ public class GremlinApiTest extends BaseApiTest {
                ".property(list, 'bar', '123')\"," +
                "\"bindings\":{}," +
                "\"language\":\"gremlin-groovy\"," +
-               "\"aliases\":{\"g\":\"__g_hugegraph\"}}";
+               "\"aliases\":{\"g\":\"__g_DEFAULT-hugegraph\"}}";
         assertResponseStatus(400, client().post(path, body));
 
         // NOTE: supply unmatch cardinality, but we give up the check
@@ -201,7 +222,7 @@ public class GremlinApiTest extends BaseApiTest {
                ".property(single, 'bar', '123')\"," +
                "\"bindings\":{}," +
                "\"language\":\"gremlin-groovy\"," +
-               "\"aliases\":{\"g\":\"__g_hugegraph\"}}";
+               "\"aliases\":{\"g\":\"__g_DEFAULT-hugegraph\"}}";
         assertResponseStatus(200, client().post(path, body));
     }
 
@@ -211,10 +232,10 @@ public class GremlinApiTest extends BaseApiTest {
                       "\"gremlin\":\"File file = new File('test.text')\"," +
                       "\"bindings\":{}," +
                       "\"language\":\"gremlin-groovy\"," +
-                      "\"aliases\":{\"g\":\"__g_hugegraph\"}}";
+                      "\"aliases\":{\"g\":\"__g_DEFAULT-hugegraph\"}}";
         Response r = client().post(path, body);
         String content = r.readEntity(String.class);
-        Assert.assertTrue(content, r.getStatus() == 200);
+        Assert.assertEquals(content, 200, r.getStatus());
         Map<?, ?> result = assertJsonContains(content, "result");
         @SuppressWarnings({"unchecked", "rawtypes"})
         Map data = ((List<Map>) assertMapContains(result, "data")).get(0);
@@ -227,7 +248,7 @@ public class GremlinApiTest extends BaseApiTest {
                       "\"gremlin\":\"g.V().order().by(desc)\"," +
                       "\"bindings\":{}," +
                       "\"language\":\"gremlin-groovy\"," +
-                      "\"aliases\":{\"g\":\"__g_hugegraph\"}}";
+                      "\"aliases\":{\"g\":\"__g_DEFAULT-hugegraph\"}}";
         Response response = client().post(path, body);
         assertResponseStatus(200, response);
     }
@@ -238,7 +259,7 @@ public class GremlinApiTest extends BaseApiTest {
                       "\"gremlin\":\"g.V().order().by(asc)\"," +
                       "\"bindings\":{}," +
                       "\"language\":\"gremlin-groovy\"," +
-                      "\"aliases\":{\"g\":\"__g_hugegraph\"}}";
+                      "\"aliases\":{\"g\":\"__g_DEFAULT-hugegraph\"}}";
         Response response = client().post(path, body);
         assertResponseStatus(200, response);
     }
@@ -249,7 +270,7 @@ public class GremlinApiTest extends BaseApiTest {
                       "\"gremlin\":\"g.E().order().by(desc)\"," +
                       "\"bindings\":{}," +
                       "\"language\":\"gremlin-groovy\"," +
-                      "\"aliases\":{\"g\":\"__g_hugegraph\"}}";
+                      "\"aliases\":{\"g\":\"__g_DEFAULT-hugegraph\"}}";
         Response response = client().post(path, body);
         assertResponseStatus(200, response);
     }
@@ -260,7 +281,7 @@ public class GremlinApiTest extends BaseApiTest {
                       "\"gremlin\":\"g.E().order().by(asc)\"," +
                       "\"bindings\":{}," +
                       "\"language\":\"gremlin-groovy\"," +
-                      "\"aliases\":{\"g\":\"__g_hugegraph\"}}";
+                      "\"aliases\":{\"g\":\"__g_DEFAULT-hugegraph\"}}";
         Response response = client().post(path, body);
         assertResponseStatus(200, response);
     }
