@@ -42,77 +42,76 @@ public class RolePermissionTest {
 
     @Test
     public void testBuiltinAdmin() {
+        String adminAll = "{\"roles\":{\"*\":{\"*\":{\"ADMIN\":{\"ALL" +
+                          "\":[{\"type\":\"ALL\",\"label\":\"write\"," +
+                          "\"properties\":null}]}}}}}";
         RolePermission admin = RolePermission.admin();
-        RolePermission role1 = RolePermission.role("admin", HugePermission.ANY);
+        RolePermission role1 = RolePermission.role("*", "*", HugePermission.ADMIN);
         Assert.assertEquals(admin, role1);
-        Assert.assertSame(admin, RolePermission.builtin(admin));
-        Assert.assertSame(admin, RolePermission.builtin(role1));
-
-        RolePermission role = RolePermission.fromJson("{\"roles\":{\"admin\":{\"ANY\":[" +
-                                                      "{\"type\":\"ALL\",\"label\":\"write\"," +
-                                                      "\"properties\":null}]}}");
+        Assert.assertEquals(admin, RolePermission.builtin(admin));
+        Assert.assertEquals(admin, RolePermission.builtin(role1));
+        RolePermission role = RolePermission.fromJson(adminAll);
         Assert.assertTrue(roleContains(admin, role));
 
         RolePermission role2 = RolePermission.all("admin");
-        Assert.assertSame(admin, RolePermission.builtin(role2));
+        Assert.assertEquals(admin, RolePermission.builtin(role2));
         Assert.assertTrue(roleContains(admin, role2));
         Assert.assertTrue(roleContains(role2, role));
 
         RolePermission hg = RolePermission.all("hg1");
-        RolePermission role3 = RolePermission.fromJson("{\"roles\":" +
-                                                       "{\"hg1\":{\"ANY\":" +
-                                                       "[{\"type\":\"ALL\",\"label\":" +
-                                                       "\"write\",\"properties\":null}" +
-                                                       "]}}");
-        Assert.assertSame(hg, RolePermission.builtin(hg));
-        Assert.assertSame(hg, RolePermission.fromJson(hg));
+        RolePermission role3 = RolePermission.fromJson(adminAll);
+        Assert.assertEquals(hg, RolePermission.builtin(hg));
+        Assert.assertEquals(hg, RolePermission.fromJson(hg));
         Assert.assertTrue(roleContains(hg, role3));
 
         /*
          * NOTE: admin role not match graph role
          * if want do this, rely on upper-layer special judgment
          */
-        Assert.assertFalse(roleContains(admin, hg));
+        Assert.assertTrue(roleContains(admin, hg));
     }
 
     @Test
     public void testBuiltinNone() {
         RolePermission none = RolePermission.none();
-        RolePermission role1 = RolePermission.role("none", HugePermission.NONE);
+        RolePermission role1 = RolePermission.role("*", "*", HugePermission.NONE);
         Assert.assertEquals(none, role1);
-        Assert.assertSame(none, RolePermission.builtin(none));
-        Assert.assertSame(none, RolePermission.builtin(role1));
+        Assert.assertEquals(none, RolePermission.builtin(none));
+        Assert.assertEquals(none, RolePermission.builtin(role1));
 
-        Assert.assertEquals("{\"roles\":{\"none\":{\"NONE\":[" +
-                            "{\"type\":\"ALL\",\"label\":\"*\",\"properties\":null}]}}}",
-                            none.toJson());
-        RolePermission role = RolePermission.fromJson("{\"roles\":{\"none\":{\"NONE\":[" +
-                                                      "{\"type\":\"ALL\",\"label\":\"write\"," +
-                                                      "\"properties\":null}]}}");
+        Assert.assertEquals("{\"roles\":{}}", none.toJson());
+        RolePermission role = RolePermission.fromJson("{\"roles\":{}}");
         Assert.assertTrue(roleContains(none, role));
     }
 
     @Test
     public void testContains() {
-        String json = "{\"roles\":" +
-                      "{\"hugegraph\":{\"READ\":[" +
-                      "{\"type\":\"EDGE\",\"label\":\"write\",\"properties\":null}," +
-                      "{\"type\":\"PROPERTY_KEY\",\"label\":\"*\",\"properties\":null}," +
-                      "{\"type\":\"VERTEX_LABEL\",\"label\":\"*\",\"properties\":null}," +
-                      "{\"type\":\"EDGE_LABEL\",\"label\":\"*\",\"properties\":null}," +
-                      "{\"type\":\"INDEX_LABEL\",\"label\":\"*\",\"properties\":null}," +
-                      "{\"type\":\"VERTEX\",\"label\":\"person\",\"properties\":" +
-                      "{\"city\":\"Beijing\",\"age\":\"P.gte(20)\"}}," +
-                      "{\"type\":\"VERTEX_LABEL\",\"label\":\"*\",\"properties\":null}," +
-                      "{\"type\":\"PROPERTY_KEY\",\"label\":\"*\",\"properties\":null}]," +
-                      "\"WRITE\":[" +
-                      "{\"type\":\"VERTEX\",\"label\":\"person\",\"properties\":" +
-                      "{\"city\":\"Beijing\",\"age\":\"P.gte(20)\"}}," +
-                      "{\"type\":\"VERTEX_LABEL\",\"label\":\"*\",\"properties\":null}," +
-                      "{\"type\":\"PROPERTY_KEY\",\"label\":\"*\",\"properties\":null}]," +
-                      "\"EXECUTE\":[" +
-                      "{\"type\":\"GREMLIN\",\"label\":\"*\",\"properties\":null}]}," +
-                      "\"hugegraph1\":{\"READ\":[]}}}";
+        String json =
+                "{\"roles\":{\"DEFAULT\":{\"hugegraph\":{\"READ\":" +
+                "{\"EDGE#write\":[{\"type\":\"EDGE\",\"label\":\"write\"," +
+                "\"properties\":null}]," +
+                "\"PROPERTY_KEY#*\":[{\"type\":\"PROPERTY_KEY\"," +
+                "\"label\":\"*\",\"properties\":null}," +
+                "{\"type\":\"PROPERTY_KEY\",\"label\":\"*\",\"properties\":null}]," +
+                "\"VERTEX_LABEL#*\":[{\"type\":\"VERTEX_LABEL\",\"label\":\"*\"," +
+                "\"properties\":null},{\"type\":\"VERTEX_LABEL\",\"label\":\"*\"," +
+                "\"properties\":null}]," +
+                "\"EDGE_LABEL#*\":[{\"type\":\"EDGE_LABEL\",\"label\":\"*\"," +
+                "\"properties\":null}]," +
+                "\"INDEX_LABEL#*\":[{\"type\":\"INDEX_LABEL\",\"label\":\"*\"," +
+                "\"properties\":null}]," +
+                "\"VERTEX#person\":[{\"type\":\"VERTEX\"," +
+                "\"label\":\"person\",\"properties\":{\"city\":\"Beijing\"," +
+                "\"age\":\"P.gte(20)\"}}]}," +
+                "\"WRITE\":{\"VERTEX#person\":[{\"type\":\"VERTEX\"," +
+                "\"label\":\"person\",\"properties\":{\"city\":\"Beijing\"," +
+                "\"age\":\"P.gte(20)\"}}]," +
+                "\"VERTEX_LABEL#*\":[{\"type\":\"VERTEX_LABEL\"," +
+                "\"label\":\"*\",\"properties\":null}]," +
+                "\"PROPERTY_KEY#*\":[{\"type\":\"PROPERTY_KEY\",\"label\":\"*\"," +
+                "\"properties\":null}]}," +
+                "\"EXECUTE\":{\"GREMLIN#*\":[{\"type\":\"GREMLIN\",\"label\":\"*\"," +
+                "\"properties\":null}]}},\"hugegraph1\":{\"READ\":{}}}}}}";
 
         RolePermission role = RolePermission.fromJson(json);
 
@@ -120,76 +119,90 @@ public class RolePermissionTest {
         Assert.assertEquals(role, r1);
         Assert.assertTrue(roleContains(role, r1));
 
-        RolePermission r2 = RolePermission.fromJson("{\"roles\":{\"hugegraph\":{\"READ\":[" +
-                                                    "{\"type\":\"EDGE\",\"label\":\"write\"," +
-                                                    "\"properties\":null}]}}");
+        RolePermission r2 = RolePermission.fromJson(
+                "{\"roles\":{\"DEFAULT\":{\"hugegraph\":{\"READ\":{\"EDGE" +
+                "#write\":[{\"type\":\"EDGE\",\"label\":\"write\"," +
+                "\"properties\":null}]}}}}");
         Assert.assertTrue(roleContains(role, r2));
 
-        RolePermission r3 = RolePermission.fromJson("{\"roles\":{\"hugegraph\":{\"READ\":[" +
-                                                    "{\"type\":\"EDGE\",\"label\":\"write\"," +
-                                                    "\"properties\":{\"date\":\"2018-8-8\"}}]}}");
+        RolePermission r3 = RolePermission.fromJson(
+                "{\"roles\":{\"DEFAULT\":{\"hugegraph\":{\"READ\":{\"EDGE" +
+                "#write\":[{\"type\":\"EDGE\",\"label\":\"write\"," +
+                "\"properties\":{\"date\":\"2018-8-8\"}}]}}}}");
         Assert.assertTrue(roleContains(role, r3));
 
-        RolePermission r4 = RolePermission.fromJson("{\"roles\":{\"hugegraph\":{\"WRITE\":[" +
-                                                    "{\"type\":\"VERTEX\",\"label\":\"person\"," +
-                                                    "\"properties\":{\"city\":\"Beijing\"," +
-                                                    "\"age\":\"P.gte(20)\"}}]}}");
+        RolePermission r4 = RolePermission.fromJson(
+                "{\"roles\":{\"DEFAULT\":{\"hugegraph\":{\"WRITE\":{\"VERTEX" +
+                "#person\":[{\"type\":\"VERTEX\",\"label\":\"person\"," +
+                "\"properties\":{\"city\":\"Beijing\",\"age\":\"P.gte(20)" +
+                "\"}}]}}}}");
         Assert.assertTrue(roleContains(role, r4));
 
-        RolePermission r5 = RolePermission.fromJson("{\"roles\":{\"hugegraph\":{\"WRITE\":[" +
-                                                    "{\"type\":\"VERTEX\",\"label\":\"person\"," +
-                                                    "\"properties\":{\"city\":\"Beijing\"," +
-                                                    "\"age\":\"P.gte(21)\"}}]}}");
+        RolePermission r5 = RolePermission.fromJson(
+                "{\"roles\":{\"DEFAULT\":{\"hugegraph\":{\"WRITE\":{\"VERTEX" +
+                "#person\":[{\"type\":\"VERTEX\",\"label\":\"person\"," +
+                "\"properties\":{\"city\":\"Beijing\",\"age\":\"P.gte(21)" +
+                "\"}}]}}}}");
         Assert.assertFalse(roleContains(role, r5));
 
-        RolePermission r6 = RolePermission.fromJson("{\"roles\":{\"hugegraph\":{\"WRITE\":[" +
-                                                    "{\"type\":\"VERTEX\",\"label\":\"person\"," +
-                                                    "\"properties\":null}]}}");
+        RolePermission r6 = RolePermission.fromJson(
+                "{\"roles\":{\"DEFAULT\":{\"hugegraph\":{\"WRITE\":{\"VERTEX" +
+                "#person\":[{\"type\":\"VERTEX\",\"label\":\"person\"," +
+                "\"properties\":null}]}}}}");
         Assert.assertFalse(roleContains(role, r6));
 
-        RolePermission r7 = RolePermission.fromJson("{\"roles\":{\"hugegraph\":{\"WRITE\":[" +
-                                                    "{\"type\":\"VERTEX\",\"label\":\"person2\"," +
-                                                    "\"properties\":{\"city\":\"Beijing\"," +
-                                                    "\"age\":\"P.gte(20)\"}}]}}");
+        RolePermission r7 = RolePermission.fromJson(
+                "{\"roles\":{\"DEFAULT\":{\"hugegraph\":{\"WRITE\":{\"VERTEX" +
+                "#person2\":[{\"type\":\"VERTEX\",\"label\":\"person2\"," +
+                "\"properties\":{\"city\":\"Beijing\",\"age\":\"P.gte(20)" +
+                "\"}}]}}}}");
         Assert.assertFalse(roleContains(role, r7));
 
-        RolePermission r8 = RolePermission.fromJson("{\"roles\":{\"hugegraph\":{\"WRITE\":[" +
-                                                    "{\"type\":\"EDGE\",\"label\":\"person\"," +
-                                                    "\"properties\":{\"city\":\"Beijing\"," +
-                                                    "\"age\":\"P.gte(20)\"}}]}}");
+        RolePermission r8 = RolePermission.fromJson(
+                "{\"roles\":{\"DEFAULT\":{\"hugegraph\":{\"WRITE\":{\"EDGE" +
+                "#person\":[{\"type\":\"EDGE\",\"label\":\"person\"," +
+                "\"properties\":{\"city\":\"Beijing\",\"age\":\"P.gte(20)" +
+                "\"}}]}}}}");
         Assert.assertFalse(roleContains(role, r8));
 
-        role = RolePermission.fromJson("{\"roles\":{\"hugegraph\":{\"READ\":[" +
-                                       "{\"type\":\"ALL\",\"label\":\"write\"," +
-                                       "\"properties\":null}]}}");
-        RolePermission r9 = RolePermission.fromJson("{\"roles\":{\"hugegraph\":{\"READ\":[" +
-                                                    "{\"type\":\"ALL\",\"label\":\"write\"," +
-                                                    "\"properties\":null}]}}");
+        role = RolePermission.fromJson(
+                "{\"roles\":{\"DEFAULT\":{\"hugegraph\":{\"READ\":{\"ALL" +
+                "#write\":[{\"type\":\"ALL\",\"label\":\"write\"," +
+                "\"properties\":null}]}}}}");
+        RolePermission r9 = RolePermission.fromJson(
+                "{\"roles\":{\"DEFAULT\":{\"hugegraph\":{\"READ\":{\"ALL" +
+                "#write\":[{\"type\":\"ALL\",\"label\":\"write\"," +
+                "\"properties\":null}]}}}}");
         Assert.assertTrue(roleContains(role, r9));
 
-        RolePermission r10 = RolePermission.fromJson("{\"roles\":{\"hugegraph\":{\"READ\":[" +
-                                                     "{\"type\":\"EDGE\",\"label\":\"write\"," +
-                                                     "\"properties\":null}]}}");
+        RolePermission r10 = RolePermission.fromJson(
+                "{\"roles\":{\"DEFAULT\":{\"hugegraph\":{\"READ\":{\"EDGE" +
+                "#write\":[{\"type\":\"EDGE\",\"label\":\"write\"," +
+                "\"properties\":null}]}}}}");
         Assert.assertTrue(roleContains(role, r10));
 
-        RolePermission r11 = RolePermission.fromJson("{\"roles\":{\"hugegraph\":{\"READ\":[" +
-                                                     "{\"type\":\"VERTEX\",\"label\":\"write\"," +
-                                                     "\"properties\":null}]}}");
+        RolePermission r11 = RolePermission.fromJson(
+                "{\"roles\":{\"DEFAULT\":{\"hugegraph\":{\"READ\":{\"VERTEX" +
+                "#write\":[{\"type\":\"VERTEX\",\"label\":\"write\"," +
+                "\"properties\":null}]}}}}");
         Assert.assertTrue(roleContains(role, r11));
 
-        RolePermission r12 = RolePermission.fromJson("{\"roles\":{\"hugegraph\":{\"READ\":[" +
-                                                     "{\"type\":\"VERTEX\",\"label\":\"person\"," +
-                                                     "\"properties\":null}]}}");
+        RolePermission r12 = RolePermission.fromJson(
+                "{\"roles\":{\"DEFAULT\":{\"hugegraph\":{\"READ\":{\"VERTEX" +
+                "#person\":[{\"type\":\"VERTEX\",\"label\":\"person\"," +
+                "\"properties\":null}]}}}}");
         Assert.assertFalse(roleContains(role, r12));
 
-        RolePermission r13 = RolePermission.fromJson("{\"roles\":{\"hugegraph\":{\"WRITE\":[" +
-                                                     "{\"type\":\"VERTEX\",\"label\":\"write\"," +
-                                                     "\"properties\":null}]}}");
+        RolePermission r13 = RolePermission.fromJson(
+                "{\"roles\":{\"DEFAULT\":{\"hugegraph\":{\"WRITE\":{\"VERTEX" +
+                "#write\":[{\"type\":\"VERTEX\",\"label\":\"write\"," +
+                "\"properties\":null}]}}}}");
         Assert.assertFalse(roleContains(role, r13));
 
-        RolePermission r14 = RolePermission.fromJson("{\"roles\":{\"hugegraph2\":{\"READ\":[" +
-                                                     "{\"type\":\"VERTEX\",\"label\":\"write\"," +
-                                                     "\"properties\":null}]}}");
+        RolePermission r14 = RolePermission.fromJson(
+                "{\"roles\":{\"DEFAULT\":{\"hugegraph2\":{\"READ\":{\"VERTEX" +
+                "#write\":[{\"type\":\"VERTEX\",\"label\":\"write\"," +
+                "\"properties\":null}]}}}}");
         Assert.assertFalse(roleContains(role, r14));
     }
 
@@ -400,14 +413,14 @@ public class RolePermissionTest {
         HugeResource vlPrefix = new HugeResource(ResourceType.VERTEX_LABEL,
                                                  "p-.*", null);
 
-        ResourceObject<?> r3 = ResourceObject.of("g1",
+        ResourceObject<?> r3 = ResourceObject.of("DEFAULT", "g1",
                                                  ResourceType.VERTEX_LABEL,
                                                  NameObject.of("test"));
         Assert.assertTrue(all.filter(r3));
         Assert.assertTrue(schema.filter(r3));
         Assert.assertFalse(vlPrefix.filter(r3));
 
-        ResourceObject<?> r4 = ResourceObject.of("g1",
+        ResourceObject<?> r4 = ResourceObject.of("DEFAULT", "g1",
                                                  ResourceType.VERTEX_LABEL,
                                                  NameObject.of("p-test"));
         Assert.assertTrue(all.filter(r4));
@@ -419,7 +432,7 @@ public class RolePermissionTest {
         VertexLabel vl1 = fo.newVertexLabel(IdGenerator.of("id1"), "person",
                                             IdStrategy.PRIMARY_KEY,
                                             IdGenerator.of("1"));
-        ResourceObject<?> r5 = ResourceObject.of("g1", vl1);
+        ResourceObject<?> r5 = ResourceObject.of("DEFAULT", "g1", vl1);
         Assert.assertTrue(all.filter(r5));
         Assert.assertTrue(schema.filter(r5));
         Assert.assertFalse(vlPrefix.filter(r5));
