@@ -43,13 +43,13 @@ public class IdUtilTest {
         Assert.assertEquals("U" + uuid, IdUtil.writeString(id));
         Assert.assertEquals(id, IdUtil.readString("U" + uuid));
 
-        id = EdgeId.parse("S1>2>3>L4");
-        Assert.assertEquals("ES1>2>3>L4", IdUtil.writeString(id));
-        Assert.assertEquals(id, IdUtil.readString("ES1>2>3>L4"));
+        id = EdgeId.parse("S1>2>3>4>L6");
+        Assert.assertEquals("ES1>2>3>4>L6", IdUtil.writeString(id));
+        Assert.assertEquals(id, IdUtil.readString("ES1>2>3>4>L6"));
 
-        id = EdgeId.parse("S1111>2222>3>L4444");
-        Assert.assertEquals("ES1111>2222>3>L4444", IdUtil.writeString(id));
-        Assert.assertEquals(id, IdUtil.readString("ES1111>2222>3>L4444"));
+        id = EdgeId.parse("S1111>2222>3>4>L6666");
+        Assert.assertEquals("ES1111>2222>3>4>L6666", IdUtil.writeString(id));
+        Assert.assertEquals(id, IdUtil.readString("ES1111>2222>3>4>L6666"));
     }
 
     @Test
@@ -70,23 +70,23 @@ public class IdUtilTest {
         Assert.assertEquals(bytes, IdUtil.writeBinString(id));
         Assert.assertEquals(id, IdUtil.readBinString(bytes));
 
-        id = EdgeId.parse("S1>2>3>L4");
-        bytes = ByteBuffer.wrap(genBytes("7e803182080233000804"));
+        id = EdgeId.parse("S1>2>2>4>L6");
+        bytes = ByteBuffer.wrap(genBytes("7e8031820802080234000806"));
         Assert.assertEquals(bytes, IdUtil.writeBinString(id));
         Assert.assertEquals(id, IdUtil.readBinString(bytes));
 
-        id = EdgeId.parse("S1111>2222>3>L4444");
-        bytes = ByteBuffer.wrap(genBytes("7e8331313131821808ae330018115c"));
+        id = EdgeId.parse("S1111>2222>3>4>L6666");
+        bytes = ByteBuffer.wrap(genBytes("7e8331313131821808ae08033400181a0a"));
         Assert.assertEquals(bytes, IdUtil.writeBinString(id));
         Assert.assertEquals(id, IdUtil.readBinString(bytes));
 
-        id = EdgeId.parse("L11111111>2222>3>L44444444");
-        bytes = ByteBuffer.wrap(genBytes("7e28a98ac7821808ae33002aa62b1c"));
+        id = EdgeId.parse("L11111111>2222>3>4>L66666666");
+        bytes = ByteBuffer.wrap(genBytes("7e28a98ac7821808ae080334002bf940aa"));
         Assert.assertEquals(bytes, IdUtil.writeBinString(id));
         Assert.assertEquals(id, IdUtil.readBinString(bytes));
 
-        id = EdgeId.parse("L-1111>2222>33>L4444");
-        bytes = ByteBuffer.wrap(genBytes("7e03a9821808ae33330018115c"));
+        id = EdgeId.parse("L-1111>2222>33>55>L7777");
+        bytes = ByteBuffer.wrap(genBytes("7e03a9821808ae0821353500181e61"));
         Assert.assertEquals(bytes, IdUtil.writeBinString(id));
         Assert.assertEquals(id, IdUtil.readBinString(bytes));
     }
@@ -106,25 +106,25 @@ public class IdUtilTest {
         Assert.assertEquals(uuid, IdUtil.writeStoredString(id));
         Assert.assertEquals(id, IdUtil.readStoredString(uuid));
 
-        id = EdgeId.parse("S1>2>3>L4");
-        Assert.assertEquals("ES1>2>3>L4", IdUtil.writeStoredString(id));
-        Assert.assertEquals(id, IdUtil.readStoredString("ES1>2>3>L4"));
+        id = EdgeId.parse("S1>2>3>4>L6");
+        Assert.assertEquals("ES1>2>3>4>L6", IdUtil.writeStoredString(id));
+        Assert.assertEquals(id, IdUtil.readStoredString("ES1>2>3>4>L6"));
 
-        id = EdgeId.parse("S1111>2222>3>L4444");
-        Assert.assertEquals("ES1111>Yj>3>L15S", IdUtil.writeStoredString(id));
-        Assert.assertEquals(id, IdUtil.readStoredString("ES1111>Yj>3>L15S"));
+        id = EdgeId.parse("S1111>2222>3>6>L4444");
+        Assert.assertEquals("ES1111>Yj>3>6>L15S", IdUtil.writeStoredString(id));
+        Assert.assertEquals(id, IdUtil.readStoredString("ES1111>Yj>3>6>L15S"));
 
-        id = EdgeId.parse("L1111>2222>3>L4444");
-        Assert.assertEquals("ELHN>Yj>3>L15S", IdUtil.writeStoredString(id));
-        Assert.assertEquals(id, IdUtil.readStoredString("ELHN>Yj>3>L15S"));
+        id = EdgeId.parse("L1111>2222>3>6>L4444");
+        Assert.assertEquals("ELHN>Yj>3>6>L15S", IdUtil.writeStoredString(id));
+        Assert.assertEquals(id, IdUtil.readStoredString("ELHN>Yj>3>6>L15S"));
 
-        id = EdgeId.parse("L11111111>2222>3>L44444444");
-        String eid = "ELfOg7>Yj>3>L2eYhS";
+        id = EdgeId.parse("L11111111>2222>3>6>L44444444");
+        String eid = "ELfOg7>Yj>3>6>L2eYhS";
         Assert.assertEquals(eid, IdUtil.writeStoredString(id));
         Assert.assertEquals(id, IdUtil.readStoredString(eid));
 
-        id = EdgeId.parse("L-1111>2222>33>L4444");
-        eid = "EL-HN>Yj>33>L15S";
+        id = EdgeId.parse("L-1111>2222>6>7>L4444");
+        eid = "EL-HN>Yj>6>7>L15S";
         Assert.assertEquals(eid, IdUtil.writeStoredString(id));
         Assert.assertEquals(id, IdUtil.readStoredString(eid));
     }
@@ -154,4 +154,22 @@ public class IdUtilTest {
         }
         return bytes;
     }
+
+    /**
+     * Converts a byte array to a hexadecimal string.
+     *
+     * @param bytes the byte array to convert
+     * @return the hexadecimal string representation of the byte array
+     */
+    private String bytesToHex(byte[] bytes) {
+        StringBuilder hexString = new StringBuilder();
+        for (byte b : bytes) {
+            String hex = Integer.toHexString(0xFF & b);
+            if (hex.length() == 1) {
+                hexString.append('0'); // pad with leading zero if needed
+            }
+            hexString.append(hex);
+        }
+        return hexString.toString();
+    }
 }
