@@ -24,33 +24,42 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ThreadPoolExecutor;
+import java.util.concurrent.atomic.AtomicBoolean;
 
 import org.apache.hugegraph.pd.common.PDException;
 import org.apache.hugegraph.pd.grpc.Metapb;
 import org.apache.hugegraph.rocksdb.access.RocksDBFactory;
 import org.apache.hugegraph.store.business.BusinessHandler;
 import org.apache.hugegraph.store.business.BusinessHandlerImpl;
-import org.apache.hugegraph.store.business.DataMover;
+import org.apache.hugegraph.store.business.DataManager;
 import org.apache.hugegraph.store.cmd.HgCmdClient;
 import org.apache.hugegraph.store.cmd.HgCmdProcessor;
-import org.apache.hugegraph.store.cmd.UpdatePartitionRequest;
-import org.apache.hugegraph.store.cmd.UpdatePartitionResponse;
+import org.apache.hugegraph.store.cmd.request.UpdatePartitionRequest;
+import org.apache.hugegraph.store.cmd.response.UpdatePartitionResponse;
+import org.apache.hugegraph.store.consts.PoolNames;
+import org.apache.hugegraph.store.listener.PartitionChangedListener;
+import org.apache.hugegraph.store.listener.StoreStateListener;
 import org.apache.hugegraph.store.meta.Partition;
 import org.apache.hugegraph.store.meta.PartitionManager;
 import org.apache.hugegraph.store.meta.ShardGroup;
 import org.apache.hugegraph.store.meta.Store;
 import org.apache.hugegraph.store.metric.HgMetricService;
 import org.apache.hugegraph.store.options.HgStoreEngineOptions;
+import org.apache.hugegraph.store.options.JobOptions;
 import org.apache.hugegraph.store.options.PartitionEngineOptions;
 import org.apache.hugegraph.store.pd.DefaultPdProvider;
 import org.apache.hugegraph.store.pd.FakePdServiceProvider;
 import org.apache.hugegraph.store.pd.PdProvider;
+import org.apache.hugegraph.store.processor.Processors;
 import org.apache.hugegraph.store.raft.RaftClosure;
 import org.apache.hugegraph.store.raft.RaftOperation;
+import org.apache.hugegraph.store.util.ExecutorUtil;
 import org.apache.hugegraph.store.util.HgRaftError;
 import org.apache.hugegraph.store.util.Lifecycle;
 
 import com.alipay.sofa.jraft.JRaftUtils;
+import com.alipay.sofa.jraft.Node;
 import com.alipay.sofa.jraft.Status;
 import com.alipay.sofa.jraft.conf.Configuration;
 import com.alipay.sofa.jraft.core.NodeMetrics;
@@ -66,11 +75,13 @@ import lombok.extern.slf4j.Slf4j;
  * The core class of the storage engine, initializing PD client and raft client
  */
 @Slf4j
-public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreStateListener {
+public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, StoreStateListener,
+                                      PartitionChangedListener {
 
-    private final static HgStoreEngine instance = new HgStoreEngine();
-    private static ConcurrentHashMap<Integer, Object> engineLocks = new ConcurrentHashMap<>();
-    // Partition raft engine, key is GraphName_PartitionID
+    private static final HgStoreEngine INSTANCE = new HgStoreEngine();
+    private static final ConcurrentHashMap<Integer, Object> engineLocks = new ConcurrentHashMap<>();
+    private static ThreadPoolExecutor uninterruptibleJobs;
+    // Partition raft engines, key is GraphName_PartitionID
     private final Map<Integer, PartitionEngine> partitionEngines = new ConcurrentHashMap<>();
     private RpcServer rpcServer;
     private HgStoreEngineOptions options;
@@ -80,14 +91,24 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
     private HeartbeatService heartbeatService;
     private BusinessHandler businessHandler;
     private HgMetricService metricService;
-    private DataMover dataMover;
+    private DataManager dataManager;
+    private final AtomicBoolean closing = new AtomicBoolean(false);
+
+    private HgStoreEngine() {
+
+    }
 
     public static HgStoreEngine getInstance() {
-        return instance;
+        return INSTANCE;
+    }
+
+    public static ThreadPoolExecutor getUninterruptibleJobs() {
+        return uninterruptibleJobs;
     }
 
     /**
-     * 1. Read StoreId, register with PD, the StoreId is generated by PD for the first registration and stored locally.
+     * 1. Read StoreId, register with PD, the StoreId is generated by PD for the first
+     * registration and stored locally.
      * 2. Registration successful, start the raft service.
      * 3. Timely send Store heartbeats and Partition heartbeats to maintain contact with PD.
      *
@@ -102,6 +123,15 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
         }
 
         this.options = opts;
+        // Move to the front
+        if (uninterruptibleJobs == null) {
+            JobOptions jobConfig = options.getJobConfig();
+            uninterruptibleJobs = ExecutorUtil.createExecutor(PoolNames.U_JOB,
+                                                              jobConfig.getUninterruptibleCore(),
+                                                              jobConfig.getUninterruptibleMax(),
+                                                              jobConfig.getUninterruptibleQueueSize(),
+                                                              false);
+        }
 
         BusinessHandlerImpl.initRocksdb(opts.getRocksdbConfig(), getRocksdbListener());
 
@@ -109,16 +139,17 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
             pdProvider = new FakePdServiceProvider(opts.getFakePdOptions());
         } else {
             pdProvider = new DefaultPdProvider(opts.getPdAddress());
-            pdProvider.addPartitionInstructionListener(new PartitionInstructionProcessor(this));
+            pdProvider.setCommandProcessors(new Processors(this));
         }
         options.setPdProvider(pdProvider);
 
         partitionManager = new PartitionManager(pdProvider, opts);
 
-        partitionManager.addPartitionChangedListener(new PartitionChangedListener());
-
+        partitionManager.addPartitionChangedListener(this);
         businessHandler = new BusinessHandlerImpl(partitionManager);
-        // Need businessHandler initialization afterwards
+        BusinessHandlerImpl.setIndexDataSize(
+                this.options.getQueryPushDownOption().getIndexSizeLimitCount());
+        // Requires businessHandler to be initialized first
         partitionManager.load();
 
         rpcServer = createRaftRpcServer(opts.getRaftAddress());
@@ -128,7 +159,7 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
             // When splitting, it has not been reported to pd in time.
             if (getPartitionEngine(ptId) != null) {
                 return getPartitionEngine(ptId).waitForLeader(
-                        options.getWaitLeaderTimeout() * 1000);
+                        options.getWaitLeaderTimeout() * 1000L);
             } else {
                 // May occur cross-partition migration
                 Metapb.Shard shard = pdProvider.getPartitionLeader(graphName, ptId);
@@ -143,11 +174,12 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
 
         metricService = HgMetricService.getInstance();
         metricService.setHgStoreEngine(this).init(null);
-
-        dataMover = opts.getDataTransfer();
-        if (dataMover != null) {
-            this.dataMover.setBusinessHandler(this.businessHandler);
-            this.dataMover.setCmdClient(hgCmdClient);
+        partitionManager.setCmdClient(hgCmdClient);
+        dataManager = opts.getDataTransfer();
+        if (dataManager != null) {
+            dataManager.setBusinessHandler(this.businessHandler);
+            dataManager.setMetaManager(partitionManager);
+            dataManager.setCmdClient(hgCmdClient);
         }
         return true;
     }
@@ -157,11 +189,14 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
      */
     private RpcServer createRaftRpcServer(String raftAddr) {
         Endpoint endpoint = JRaftUtils.getEndPoint(raftAddr);
+        //TODO verify this implementation is correct
         RpcServer rpcServer = RaftRpcServerFactory.createRaftRpcServer(endpoint,
+                                                                       JRaftUtils.createExecutor(
+                                                                               "RAFT-BASIC-RPC-",
+                                                                               options.getRaftRpcThreadPoolSizeOfBasic()),
                                                                        JRaftUtils.createExecutor(
                                                                                "RAFT-RPC-",
-                                                                               options.getRaftRpcThreadPoolSize()),
-                                                                       null);
+                                                                               options.getRaftRpcThreadPoolSize()));
         HgCmdProcessor.registerProcessor(rpcServer, this);
         rpcServer.init(null);
         return rpcServer;
@@ -172,16 +207,30 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
         if (rpcServer == null) {
             return;
         }
-        partitionEngines.forEach((k, v) -> {
-            v.shutdown();
+        closing.set(true);
+        heartbeatService.shutdown();
+        metricService.shutdown();
+// Use sequential processing for safer shutdown
+        partitionEngines.values().forEach(pe -> {
+            try {
+                Node raftNode = pe.getRaftNode();
+                if (raftNode.isLeader(false)) {
+                    Status status = raftNode.transferLeadershipTo(PeerId.ANY_PEER);
+                    if (!status.isOk()) {
+                        log.warn("transfer leader error: {}", status);
+                    }
+                }
+            } catch (Exception e) {
+                log.error("transfer leader error: ", e);
+            }
+            pe.shutdown();
+            businessHandler.closeDB(pe.getGroupId());
         });
         partitionEngines.clear();
         rpcServer.shutdown();
         // HgStoreEngine.init function check rpcServer whether is null, skipped if the instance
         // exists even shut down.
         rpcServer = null;
-        heartbeatService.shutdown();
-        metricService.shutdown();
         // close all db session
         RocksDBFactory.getInstance().releaseAllGraphDB();
     }
@@ -246,17 +295,7 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
                 if (partitions.size() > 0) {
                     var shards = pdProvider.getShardGroup(partId).getShardsList();
                     if (shards.stream().anyMatch(s -> s.getStoreId() == storeId)) {
-                        var peers = partitionManager.shards2Peers(shards);
-                        Configuration initConf = engine.getOptions().getConf();
-                        if (initConf == null) {
-                            engine.getOptions().setPeerList(peers);
-                        } else {
-                            peers.stream()
-                                 .forEach(peer -> initConf.addPeer(JRaftUtils.getPeerId(peer)));
-                        }
-
-                        // engine.getOptions().getConf().setPeers();
-                        engine.restartRaftNode();
+                        restartPartitionEngine(engine, shards);
                     }
                 }
             } catch (PDException e) {
@@ -265,6 +304,42 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
         });
     }
 
+    public void handleShardGroupOp(int groupId, List<Metapb.Shard> shards) {
+        log.info("handleShardGroupOp, groupId: {}, shards: {}", groupId, shards);
+
+        var engine = getPartitionEngine(groupId);
+
+        if (engine != null) {
+            if (shards.stream()
+                      .anyMatch(s -> s.getStoreId() == partitionManager.getStore().getId())) {
+                restartPartitionEngine(engine, shards);
+            } else {
+                destroyPartitionEngine(groupId, List.copyOf(engine.getPartitions().keySet()));
+                engine.getPartitions().forEach((g, p) -> engine.removePartition(g));
+                engine.shutdown();
+            }
+        }
+    }
+
+    /**
+     * Start partition engine with new configuration, typically used for raft address changes or
+     * manual partition adjustments
+     *
+     * @param engine partition engine
+     * @param shards shard list
+     */
+    private void restartPartitionEngine(PartitionEngine engine, List<Metapb.Shard> shards) {
+        var peers = partitionManager.shards2Peers(shards);
+        Configuration initConf = engine.getOptions().getConf();
+        if (initConf == null) {
+            engine.getOptions().setPeerList(peers);
+        } else {
+            peers.stream().forEach(peer -> initConf.addPeer(JRaftUtils.getPeerId(peer)));
+        }
+        // engine.getOptions().getConf().setPeers();
+        engine.restartRaftNode();
+    }
+
     /**
      * Create raft Node
      *
@@ -282,22 +357,23 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
         return createPartitionEngine(partition.getId(), shardGroup, conf);
     }
 
-    private PartitionEngine createPartitionEngine(int groupId, ShardGroup shardGroup,
-                                                  Configuration conf) {
+    public PartitionEngine createPartitionEngine(int groupId, ShardGroup shardGroup,
+                                                 Configuration conf) {
         PartitionEngine engine;
         if ((engine = partitionEngines.get(groupId)) == null) {
             engineLocks.computeIfAbsent(groupId, k -> new Object());
             synchronized (engineLocks.get(groupId)) {
-                // Special cases during partition splitting (different number of graph partitions in the cluster) can cause the splitting partition not to be on this machine.
+                // Special cases during partition splitting (different number of graph partitions
+                // in the cluster) can cause the splitting partition not to be on this machine.
                 if (conf != null) {
                     var list = conf.listPeers();
                     list.addAll(conf.listLearners());
-                    if (!list.stream().anyMatch(
-                            p -> p.getEndpoint().toString().equals(options.getRaftAddress()))) {
-                        log.info(
-                                "raft {}, conf {} does not contains raft address:{}, skipped " +
-                                "create partition engine",
-                                groupId, conf, options.getRaftAddress());
+                    if (!list.stream()
+                             .anyMatch(p -> p.getEndpoint().toString()
+                                             .equals(options.getRaftAddress()))) {
+                        log.info("raft {}, conf {} does not contains raft address:{}, skipped " +
+                                 "create partition engine", groupId, conf,
+                                 options.getRaftAddress());
                         return null;
                     }
                 } else {
@@ -341,7 +417,8 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
     }
 
     /**
-     * Create raft group, in addition to creating the local raft node, also need to notify other peers to create raft nodes.
+     * Create raft group, in addition to creating the local raft node, also need to notify other
+     * peers to create raft nodes.
      * 1. Traverse partition.shards
      * 2. Retrieve Store information based on storeId
      * 3. Establish Raft RPC to other stores, send StartRaft messages.
@@ -365,14 +442,14 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
                     if (store == null || partitionManager.isLocalStore(store)) {
                         return;
                     }
-                    // Send messages to other peers, create raft groups. This is an asynchronous send.
+                    // Send messages to other peers, create raft groups. This is an asynchronous
+                    // send.
                     hgCmdClient.createRaftNode(store.getRaftAddress(), List.of(partition),
                                                status -> {
-                                                   log.info(
-                                                           "send to {} createRaftNode rpc call " +
-                                                           "result {} partitionId {}",
-                                                           store.getRaftAddress(), status,
-                                                           partition.getId());
+                                                   log.info("send to {} createRaftNode rpc call " +
+                                                            "result {} partitionId {}",
+                                                            store.getRaftAddress(), status,
+                                                            partition.getId());
                                                });
                 });
             }
@@ -393,14 +470,10 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
                 }
                 // Send messages to other peers, create raft groups. This is an asynchronous send.
                 hgCmdClient.destroyRaftNode(store.getRaftAddress(),
-                                            Arrays.asList(new Partition[]{partition}),
-                                            status -> {
-                                                log.info(
-                                                        "send to {} - {} DestroyRaftNode rpc call" +
-                                                        " result {}",
-                                                        store.getRaftAddress(), partition.getId(),
-                                                        status);
-                                            });
+                                            Arrays.asList(partition), status -> {
+                            log.info("send to {} - {} DestroyRaftNode rpc call" + " result {}",
+                                     store.getRaftAddress(), partition.getId(), status);
+                        });
             });
         }
     }
@@ -425,6 +498,8 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
             partitionEngines.remove(groupId);
             // Delete the corresponding db folder
             businessHandler.destroyGraphDB(graphNames.get(0), groupId);
+            // delete partition db location information
+            getPartitionManager().getStoreMetadata().removePartitionStore(groupId);
         } else {
             graphNames.forEach(graphName -> {
                 businessHandler.dbCompaction(graphName, groupId);
@@ -517,8 +592,8 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
         this.partitionManager = ptm;
     }
 
-    public DataMover getDataMover() {
-        return dataMover;
+    public DataManager getDataManager() {
+        return dataManager;
     }
 
     public PdProvider getPdProvider() {
@@ -569,9 +644,10 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
                     Partition partition = partitionManager.findPartition(graphName, partId);
                     if (partition != null) {
                         engine = this.createPartitionGroups(partition);
-                        // May migrate, should not create, put in synchronize block, avoid subsequent ones.
+                        // May migrate, should not create, put in synchronize block, avoid
+                        // subsequent ones.
                         if (engine != null) {
-                            engine.waitForLeader(options.getWaitLeaderTimeout() * 1000);
+                            engine.waitForLeader(options.getWaitLeaderTimeout() * 1000L);
                         }
                     }
                 }
@@ -580,7 +656,7 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
 
         if (engine != null) {
             // Waiting for Leader
-            Endpoint leader = engine.waitForLeader(options.getWaitLeaderTimeout() * 1000);
+            Endpoint leader = engine.waitForLeader(options.getWaitLeaderTimeout() * 1000L);
             if (engine.isLeader()) {
                 engine.addRaftTask(operation, closure);
             } else if (leader != null) {
@@ -588,7 +664,8 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
                 Store store = partitionManager.getStoreByRaftEndpoint(engine.getShardGroup(),
                                                                       leader.toString());
                 if (store.getId() == 0) {
-                    // Local store information for the Leader was not found, possibly the Partition has not been synchronized yet, reacquire from the Leader.
+                    // Local store information for the Leader was not found, possibly the
+                    // Partition has not been synchronized yet, reacquire from the Leader.
                     Store leaderStore = hgCmdClient.getStoreInfo(leader.toString());
                     store = leaderStore != null ? leaderStore : store;
                     log.error("getStoreByRaftEndpoint error store:{}, shard: {}, leader is {}",
@@ -670,57 +747,59 @@ public class HgStoreEngine implements Lifecycle<HgStoreEngineOptions>, HgStoreSt
         };
     }
 
-    class PartitionChangedListener implements PartitionManager.PartitionChangedListener {
+    public HgStoreEngineOptions getOption() {
+        return this.options;
+    }
 
-        /**
-         * Partition object changes, leader notifies other followers.
-         */
-        @Override
-        public void onChanged(Partition partition) {
-            PartitionEngine engine = getPartitionEngine(partition.getId());
+    /**
+     * Partition object changes, leader notifies other followers.
+     */
+    @Override
+    public void onChanged(Partition partition) {
+        PartitionEngine engine = getPartitionEngine(partition.getId());
 
-            if (engine != null && engine.isLeader()) {
-                try {
-                    engine.addRaftTask(RaftOperation.create(RaftOperation.SYNC_PARTITION,
-                                                            partition.getProtoObj()),
-                                       new RaftClosure() {
-                                           @Override
-                                           public void run(Status status) {
-                                               log.info(
-                                                       "Partition {}-{}-{} sync partition status " +
-                                                       "is {}",
-                                                       partition.getGraphName(), partition.getId(),
-                                                       partition.getWorkState(),
-                                                       status);
-                                           }
-                                       });
-                } catch (IOException e) {
-                    log.error("Partition {}-{} sync partition exception {}",
-                              partition.getGraphName(), partition.getId(), e);
-                }
-            }
-        }
-
-        /**
-         * Partition object key range, status changes, notify other followers by actively finding the leader.
-         */
-        @Override
-        public UpdatePartitionResponse rangeOrStateChanged(UpdatePartitionRequest request) {
-            UpdatePartitionResponse response = null;
+        if (engine != null && engine.isLeader()) {
             try {
-                response = hgCmdClient.raftUpdatePartition(request);
-
-                log.info("not leader request threadId:{} pId:{} range:{}-{} state:{} response:{}",
-                         Thread.currentThread().getId(), request.getPartitionId(),
-                         request.getStartKey(),
-                         request.getEndKey(), request.getWorkState(), response.getStatus());
-
-            } catch (Exception e) {
-                e.printStackTrace();
+                engine.addRaftTask(
+                        RaftOperation.create(RaftOperation.SYNC_PARTITION, partition.getProtoObj()),
+                        new RaftClosure() {
+                            @Override
+                            public void run(Status status) {
+                                log.info("Partition {}-{}-{} sync partition status is {}",
+                                         partition.getGraphName(), partition.getId(),
+                                         partition.getWorkState(), status);
+                            }
+                        });
+            } catch (IOException e) {
+                log.error("Partition {}-{} sync partition exception {}", partition.getGraphName(),
+                          partition.getId(), e);
             }
+        }
+    }
 
-            return response;
+    /**
+     * Partition object key range, status changes, notify other followers by actively finding the
+     * leader.
+     */
+    @Override
+    public UpdatePartitionResponse rangeOrStateChanged(UpdatePartitionRequest request) {
+        UpdatePartitionResponse response = null;
+        try {
+            response = hgCmdClient.raftUpdatePartition(request);
+
+            log.info("not leader request threadId:{} pId:{} range:{}-{} state:{} response:{}",
+                     Thread.currentThread().getId(), request.getPartitionId(),
+                     request.getStartKey(), request.getEndKey(), request.getWorkState(),
+                     response.getStatus());
+
+        } catch (Exception e) {
+            e.printStackTrace();
         }
 
+        return response;
+    }
+
+    public AtomicBoolean isClosing() {
+        return closing;
     }
 }
